@@ -1,12 +1,13 @@
 /**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
 CKEDITOR.plugins.setLang( 'codesnippet', 'en', {
-	button: 'Insert code snippet',
+	button: 'Insert Code Snippet',
 	codeContents: 'Code content',
 	emptySnippetError: 'A code snippet cannot be empty.',
 	language: 'Language',
-	title: 'Code snippet'
+	title: 'Code snippet',
+	pathName: 'code snippet'
 } );
