@@ -1,12 +1,13 @@
 /**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
 CKEDITOR.plugins.setLang( 'codesnippet', 'tt', {
 	button: 'Код өзеген өстәү',
 	codeContents: 'Код эчтәлеге',
-	emptySnippetError: 'Код өзеге буш булмаска тиеш',
+	emptySnippetError: 'Код өзеге буш булмаска тиеш.',
 	language: 'Тел',
-	title: 'Код өзеге'
+	title: 'Код өзеге',
+	pathName: 'код өзеге'
 } );
