@@ -1,11 +1,11 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'colordialog', 'ko', {
-	clear: '제거',
-	highlight: '하이라이트',
+	clear: '비우기',
+	highlight: '강조',
 	options: '색상 옵션',
-	selected: '색상 선택됨',
+	selected: '선택된 색상',
 	title: '색상 선택'
 } );
