@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'colordialog', 'sk', {
@@ -7,5 +7,5 @@ CKEDITOR.plugins.setLang( 'colordialog', 'sk', {
 	highlight: 'Zvýrazniť',
 	options: 'Možnosti farby',
 	selected: 'Vybraná farba',
-	title: 'Vyberte farbu'
+	title: 'Vybrať farbu'
 } );
