@@ -1,5 +1,5 @@
-﻿/**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
@@ -7,6 +7,6 @@ CKEDITOR.plugins.setLang( 'devtools', 'de', {
 	title: 'Elementinformation',
 	dialogName: 'Dialogfenstername',
 	tabName: 'Reitername',
-	elementId: 'Element ID',
+	elementId: 'Elementkennung',
 	elementType: 'Elementtyp'
 } );
