@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'div', 'bg', {
@@ -7,13 +7,13 @@ CKEDITOR.plugins.setLang( 'div', 'bg', {
 	advisoryTitleInputLabel: 'Препоръчително заглавие',
 	cssClassInputLabel: 'Класове за CSS',
 	edit: 'Промяна на Div',
-	inlineStyleInputLabel: 'Inline Style', // MISSING
+	inlineStyleInputLabel: 'В редица',
 	langDirLTRLabel: 'Ляво на Дясно (ЛнД)',
 	langDirLabel: 'Посока на езика',
 	langDirRTLLabel: 'Дясно на Ляво (ДнЛ)',
 	languageCodeInputLabel: ' Код на езика',
 	remove: 'Премахване на Div',
 	styleSelectLabel: 'Стил',
-	title: 'Create Div Container', // MISSING
-	toolbar: 'Create Div Container' // MISSING
+	title: 'Създай Div блок',
+	toolbar: 'Създаване на Div контейнер'
 } );
