@@ -1,19 +1,19 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'div', 'de', {
-	IdInputLabel: 'Id',
+	IdInputLabel: 'Kennung',
 	advisoryTitleInputLabel: 'Tooltip',
-	cssClassInputLabel: 'Stylesheet Klasse',
+	cssClassInputLabel: 'Formatvorlagenklasse',
 	edit: 'Div bearbeiten',
 	inlineStyleInputLabel: 'Inline Stil',
 	langDirLTRLabel: 'Links nach Rechs (LTR)',
-	langDirLabel: 'Sprache Richtung',
+	langDirLabel: 'Sprachrichtung',
 	langDirRTLLabel: 'Rechs nach Links (RTL)',
-	languageCodeInputLabel: 'Sprachenkürzel',
+	languageCodeInputLabel: 'Sprachcode',
 	remove: 'Div entfernen',
-	styleSelectLabel: 'Style',
+	styleSelectLabel: 'Stil',
 	title: 'Div Container erzeugen',
 	toolbar: 'Div Container erzeugen'
 } );
