@@ -1,19 +1,19 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'div', 'ko', {
 	IdInputLabel: 'ID',
-	advisoryTitleInputLabel: 'Advisory Title',
-	cssClassInputLabel: 'Stylesheet Classes',
-	edit: 'Div 태그 수정',
+	advisoryTitleInputLabel: '보조 제목',
+	cssClassInputLabel: '스타일 시트 클래스',
+	edit: 'Div 편집',
 	inlineStyleInputLabel: '인라인 스타일',
 	langDirLTRLabel: '왼쪽에서 오른쪽 (LTR)',
-	langDirLabel: '쓰기 방향',
+	langDirLabel: '언어 방향',
 	langDirRTLLabel: '오른쪽에서 왼쪽 (RTL)',
-	languageCodeInputLabel: '언어 코드',
+	languageCodeInputLabel: ' 언어 코드',
 	remove: 'Div 태그 삭제',
-	styleSelectLabel: 'Style',
+	styleSelectLabel: '스타일',
 	title: 'Div 태그 생성',
 	toolbar: 'Div 태그 생성'
 } );
