@@ -1,19 +1,19 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'div', 'ro', {
 	IdInputLabel: 'Id',
 	advisoryTitleInputLabel: 'Titlul consultativ',
 	cssClassInputLabel: 'Clasele cu stilul paginii (CSS)',
-	edit: 'Edit Div', // MISSING
-	inlineStyleInputLabel: 'Inline Style', // MISSING
+	edit: 'Modifică Div-ul',
+	inlineStyleInputLabel: 'Stil Inline',
 	langDirLTRLabel: 'stânga-dreapta (LTR)',
 	langDirLabel: 'Direcţia cuvintelor',
 	langDirRTLLabel: 'dreapta-stânga (RTL)',
 	languageCodeInputLabel: 'Codul limbii',
-	remove: 'Remove Div', // MISSING
+	remove: 'Șterge Div-ul',
 	styleSelectLabel: 'Stil',
-	title: 'Create Div Container', // MISSING
-	toolbar: 'Create Div Container' // MISSING
+	title: 'Crează un container Div',
+	toolbar: 'Crează un container Div'
 } );
