@@ -1,29 +1,29 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'docprops', 'de', {
 	bgColor: 'Hintergrundfarbe',
-	bgFixed: 'feststehender Hintergrund',
-	bgImage: 'Hintergrundbild URL',
-	charset: 'Zeichenkodierung',
+	bgFixed: 'Nichtrollender (feststehender) Hintergrund',
+	bgImage: 'Hintergrundbild-URL',
+	charset: 'Zeichensatzkodierung',
 	charsetASCII: 'ASCII',
 	charsetCE: 'Zentraleuropäisch',
 	charsetCR: 'Kyrillisch',
-	charsetCT: 'traditionell Chinesisch (Big5)',
+	charsetCT: 'Traditionelles Chinesisch (Big5)',
 	charsetGR: 'Griechisch',
 	charsetJP: 'Japanisch',
 	charsetKR: 'Koreanisch',
-	charsetOther: 'Andere Zeichenkodierung',
+	charsetOther: 'Andere Zeichensatzkodierung',
 	charsetTR: 'Türkisch',
 	charsetUN: 'Unicode (UTF-8)',
 	charsetWE: 'Westeuropäisch',
-	chooseColor: 'Wählen',
+	chooseColor: 'Auswählen',
 	design: 'Design',
 	docTitle: 'Seitentitel',
-	docType: 'Dokumententyp',
-	docTypeOther: 'Anderer Dokumententyp',
-	label: 'Dokument-Eigenschaften',
+	docType: 'Dokumententypüberschrift',
+	docTypeOther: 'Andere Dokumententypüberschrift',
+	label: 'Dokumenteigenschaften',
 	margin: 'Seitenränder',
 	marginBottom: 'Unten',
 	marginLeft: 'Links',
@@ -32,11 +32,11 @@ CKEDITOR.plugins.setLang( 'docprops', 'de', {
 	meta: 'Metadaten',
 	metaAuthor: 'Autor',
 	metaCopyright: 'Copyright',
-	metaDescription: 'Dokument-Beschreibung',
+	metaDescription: 'Dokumentbeschreibung',
 	metaKeywords: 'Schlüsselwörter (durch Komma getrennt)',
-	other: '<andere>',
+	other: 'Andere...',
 	previewHtml: '<p>Das ist ein <strong>Beispieltext</strong>. Du schreibst in <a href="javascript:void(0)">CKEditor</a>.</p>',
-	title: 'Dokument-Eigenschaften',
+	title: 'Dokumenteigenschaften',
 	txtColor: 'Textfarbe',
 	xhtmlDec: 'Beziehe XHTML Deklarationen ein'
 } );
