@@ -1,8 +1,8 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'elementspath', 'pt', {
-	eleLabel: 'Camninho dos Elementos',
+	eleLabel: 'Caminho dos elementos',
 	eleTitle: 'Elemento %1'
 } );
