@@ -1,5 +1,5 @@
-﻿/**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
@@ -42,6 +42,10 @@
 			if ( !range )
 				return;
 
+			// When range is in nested editable, we have to replace range with this one,
+			// which have root property set to closest editable, to make auto paragraphing work. (#12162)
+			range = replaceRangeWithClosestEditableRoot( range );
+
 			var doc = range.document;
 
 			var atBlockStart = range.checkStartOfBlock(),
@@ -108,29 +112,36 @@
 						//      </li>                    =>          </li>
 						//  </ul>                        =>      </ul>
 
-						if ( firstChild || lastChild )
-							block[ firstChild ? 'insertBefore' : 'insertAfter' ]( blockGrandParent );
+						if ( firstChild || lastChild ) {
 
-						// If the empty block is neither first nor last child
-						// then split the list and the block as an element
-						// of outer list.
-						//
-						//                              =>      <ul>
-						//                              =>          <li>
-						//  <ul>                        =>              <ul>
-						//      <li>                    =>                  <li>x</li>
-						//          <ul>                =>              </ul>
-						//              <li>x</li>      =>          </li>
-						//              <li>^</li>      =>          <li>^</li>
-						//              <li>y</li>      =>          <li>
-						//          </ul>               =>              <ul>
-						//      </li>                   =>                  <li>y</li>
-						//  </ul>                       =>              </ul>
-						//                              =>          </li>
-						//                              =>      </ul>
+							// If it's only child, we don't want to keep perent ul anymore.
+							if ( firstChild && lastChild ) {
+								blockParent.remove();
+							}
 
-						else
+							block[lastChild ? 'insertAfter' : 'insertBefore']( blockGrandParent );
+
+							// If the empty block is neither first nor last child
+							// then split the list and the block as an element
+							// of outer list.
+							//
+							//                              =>      <ul>
+							//                              =>          <li>
+							//  <ul>                        =>              <ul>
+							//      <li>                    =>                  <li>x</li>
+							//          <ul>                =>              </ul>
+							//              <li>x</li>      =>          </li>
+							//              <li>^</li>      =>          <li>^</li>
+							//              <li>y</li>      =>          <li>
+							//          </ul>               =>              <ul>
+							//      </li>                   =>                  <li>y</li>
+							//  </ul>                       =>              </ul>
+							//                              =>          </li>
+							//                              =>      </ul>
+
+						} else {
 							block.breakParent( blockGrandParent );
+						}
 					}
 
 					else if ( !needsBlock ) {
@@ -185,7 +196,7 @@
 							newBlock = doc.createElement( mode == CKEDITOR.ENTER_P ? 'p' : 'div' );
 
 							if ( dirLoose )
-								newBlock.setAttribute('dir', orgDir);
+								newBlock.setAttribute( 'dir', orgDir );
 
 							style && newBlock.setAttribute( 'style', style );
 							className && newBlock.setAttribute( 'class', className );
@@ -194,8 +205,9 @@
 							block.moveChildren( newBlock );
 						}
 						// The original path block is not a list item, just copy the block to out side of the list.
-						else
+						else {
 							newBlock = path.block;
+						}
 
 						// If block is the first or last child of the parent
 						// list, move it out of the list:
@@ -329,8 +341,9 @@
 						// Otherwise, duplicate the previous block.
 						newBlock = previousBlock.clone();
 					}
-				} else if ( nextBlock )
+				} else if ( nextBlock ) {
 					newBlock = nextBlock.clone();
+				}
 
 				if ( !newBlock ) {
 					// We have already created a new list item. (#6849)
@@ -343,8 +356,9 @@
 					}
 				}
 				// Force the enter block unless we're talking of a list item.
-				else if ( forceMode && !newBlock.is( 'li' ) )
+				else if ( forceMode && !newBlock.is( 'li' ) ) {
 					newBlock.renameNode( blockTag );
+				}
 
 				// Recreate the inline elements tree, which was available
 				// before hitting enter, so the same styles will be available in
@@ -404,9 +418,6 @@
 
 			var doc = range.document;
 
-			// Determine the block element to be used.
-			var blockTag = ( mode == CKEDITOR.ENTER_DIV ? 'div' : 'p' );
-
 			var isEndOfBlock = range.checkEndOfBlock();
 
 			var elementPath = new CKEDITOR.dom.elementPath( editor.getSelection().getStartElement() );
@@ -414,8 +425,6 @@
 			var startBlock = elementPath.block,
 				startBlockTag = startBlock && elementPath.block.getName();
 
-			var isPre = false;
-
 			if ( !forceMode && startBlockTag == 'li' ) {
 				enterBlock( editor, mode, range, forceMode );
 				return;
@@ -539,4 +548,19 @@
 		// Return the first range.
 		return ranges[ 0 ];
 	}
+
+	function replaceRangeWithClosestEditableRoot( range ) {
+		var closestEditable = range.startContainer.getAscendant( function( node ) {
+			return node.type == CKEDITOR.NODE_ELEMENT && node.getAttribute( 'contenteditable' ) == 'true';
+		}, true );
+
+		if ( range.root.equals( closestEditable ) ) {
+			return range;
+		} else {
+			var newRange = new CKEDITOR.dom.range( closestEditable );
+
+			newRange.moveToRange( range );
+			return newRange;
+		}
+	}
 } )();
