@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'forms', 'en-gb', {
@@ -15,7 +15,8 @@ CKEDITOR.plugins.setLang( 'forms', 'en-gb', {
 		checkboxTitle: 'Checkbox Properties',
 		radioTitle: 'Radio Button Properties',
 		value: 'Value',
-		selected: 'Selected'
+		selected: 'Selected',
+		required: 'Required' // MISSING
 	},
 	form: {
 		title: 'Form Properties',
@@ -37,6 +38,7 @@ CKEDITOR.plugins.setLang( 'forms', 'en-gb', {
 		size: 'Size',
 		lines: 'lines',
 		chkMulti: 'Allow multiple selections',
+		required: 'Required', // MISSING
 		opText: 'Text',
 		opValue: 'Value',
 		btnAdd: 'Add',
@@ -57,6 +59,7 @@ CKEDITOR.plugins.setLang( 'forms', 'en-gb', {
 		value: 'Value',
 		charWidth: 'Character Width',
 		maxChars: 'Maximum Characters',
+		required: 'Required', // MISSING
 		type: 'Type',
 		typeText: 'Text',
 		typePass: 'Password',
