@@ -1,5 +1,5 @@
-﻿/**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/**
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
@@ -34,8 +34,9 @@
 									value = Math.round( oImageOriginal.$.width * ( value / oImageOriginal.$.height ) );
 								if ( !isNaN( value ) )
 									dialog.setValueOf( 'info', 'txtWidth', value );
-							} else //this.id = txtWidth.
-							{
+							}
+							// this.id = txtWidth.
+							else {
 								if ( value && value != '0' )
 									value = Math.round( oImageOriginal.$.height * ( value / oImageOriginal.$.width ) );
 								if ( !isNaN( value ) )
@@ -126,7 +127,7 @@
 									dialog.lockRatio = true;
 							}
 						}
-					} else if ( value != undefined )
+					} else if ( value !== undefined )
 						dialog.lockRatio = value;
 					else {
 						dialog.userlockRatio = 1;
@@ -150,13 +151,25 @@
 					return dialog.lockRatio;
 				};
 
-			var resetSize = function( dialog ) {
-					var oImageOriginal = dialog.originalElement;
-					if ( oImageOriginal.getCustomData( 'isReady' ) == 'true' ) {
+			var resetSize = function( dialog, emptyValues ) {
+					var oImageOriginal = dialog.originalElement,
+						ready = oImageOriginal.getCustomData( 'isReady' ) == 'true';
+
+					if ( ready ) {
 						var widthField = dialog.getContentElement( 'info', 'txtWidth' ),
-							heightField = dialog.getContentElement( 'info', 'txtHeight' );
-						widthField && widthField.setValue( oImageOriginal.$.width );
-						heightField && heightField.setValue( oImageOriginal.$.height );
+							heightField = dialog.getContentElement( 'info', 'txtHeight' ),
+							widthValue, heightValue;
+
+						if ( emptyValues ) {
+							widthValue = 0;
+							heightValue = 0;
+						} else {
+							widthValue = oImageOriginal.$.width;
+							heightValue = oImageOriginal.$.height;
+						}
+
+						widthField && widthField.setValue( widthValue );
+						heightField && heightField.setValue( heightValue );
 					}
 					updatePreview( dialog );
 				};
@@ -168,8 +181,8 @@
 					function checkDimension( size, defaultValue ) {
 						var aMatch = size.match( regexGetSize );
 						if ( aMatch ) {
-							if ( aMatch[ 2 ] == '%' ) // % is allowed.
-							{
+							// % is allowed.
+							if ( aMatch[ 2 ] == '%' ) {
 								aMatch[ 1 ] += '%';
 								switchLockRatio( dialog, false ); // Unlock ratio
 							}
@@ -194,31 +207,41 @@
 
 			var onImgLoadEvent = function() {
 					// Image is ready.
-					var original = this.originalElement;
+					var original = this.originalElement,
+						loader = CKEDITOR.document.getById( imagePreviewLoaderId );
+
 					original.setCustomData( 'isReady', 'true' );
 					original.removeListener( 'load', onImgLoadEvent );
 					original.removeListener( 'error', onImgLoadErrorEvent );
 					original.removeListener( 'abort', onImgLoadErrorEvent );
 
-					// Hide loader
-					CKEDITOR.document.getById( imagePreviewLoaderId ).setStyle( 'display', 'none' );
+					// Hide loader.
+					if ( loader )
+						loader.setStyle( 'display', 'none' );
 
-					// New image -> new domensions
-					if ( !this.dontResetSize )
-						resetSize( this );
+					// New image -> new dimensions
+					if ( !this.dontResetSize ) {
+						resetSize( this, editor.config.image_prefillDimensions === false );
+					}
 
-					if ( this.firstLoad )
+					if ( this.firstLoad ) {
 						CKEDITOR.tools.setTimeout( function() {
-						switchLockRatio( this, 'check' );
-					}, 0, this );
+							switchLockRatio( this, 'check' );
+						}, 0, this );
+					}
 
 					this.firstLoad = false;
 					this.dontResetSize = false;
+
+					// Possible fix for #12818.
+					updatePreview( this );
 				};
 
 			var onImgLoadErrorEvent = function() {
 					// Error. Image is not loaded.
-					var original = this.originalElement;
+					var original = this.originalElement,
+						loader = CKEDITOR.document.getById( imagePreviewLoaderId );
+
 					original.removeListener( 'load', onImgLoadEvent );
 					original.removeListener( 'error', onImgLoadErrorEvent );
 					original.removeListener( 'abort', onImgLoadErrorEvent );
@@ -229,8 +252,10 @@
 					if ( this.preview )
 						this.preview.setAttribute( 'src', noimage );
 
-					// Hide loader
-					CKEDITOR.document.getById( imagePreviewLoaderId ).setStyle( 'display', 'none' );
+					// Hide loader.
+					if ( loader )
+						loader.setStyle( 'display', 'none' );
+
 					switchLockRatio( this, false ); // Unlock.
 				};
 
@@ -264,10 +289,13 @@
 					var editor = this.getParentEditor(),
 						sel = editor.getSelection(),
 						element = sel && sel.getSelectedElement(),
-						link = element && editor.elementPath( element ).contains( 'a', 1 );
+						link = element && editor.elementPath( element ).contains( 'a', 1 ),
+						loader = CKEDITOR.document.getById( imagePreviewLoaderId );
+
+					// Hide loader.
+					if ( loader )
+						loader.setStyle( 'display', 'none' );
 
-					//Hide loader.
-					CKEDITOR.document.getById( imagePreviewLoaderId ).setStyle( 'display', 'none' );
 					// Create the preview before setup the dialog contents.
 					previewPreloader = new CKEDITOR.dom.element( 'img', editor.document );
 					this.preview = CKEDITOR.document.getById( previewImageId );
@@ -281,17 +309,23 @@
 						this.linkElement = link;
 						this.linkEditMode = true;
 
+						// If there is an existing link, by default keep it (true).
+						// It will be removed if certain conditions are met and Link tab is enabled. (#13351)
+						this.addLink = true;
+
 						// Look for Image element.
 						var linkChildren = link.getChildren();
-						if ( linkChildren.count() == 1 ) // 1 child.
-						{
-							var childTagName = linkChildren.getItem( 0 ).getName();
-							if ( childTagName == 'img' || childTagName == 'input' ) {
-								this.imageElement = linkChildren.getItem( 0 );
-								if ( this.imageElement.getName() == 'img' )
-									this.imageEditMode = 'img';
-								else if ( this.imageElement.getName() == 'input' )
-									this.imageEditMode = 'input';
+						if ( linkChildren.count() == 1 ) {
+							var childTag = linkChildren.getItem( 0 );
+
+							if ( childTag.type == CKEDITOR.NODE_ELEMENT ) {
+								if ( childTag.is( 'img' ) || childTag.is( 'input' ) ) {
+									this.imageElement = linkChildren.getItem( 0 );
+									if ( this.imageElement.is( 'img' ) )
+										this.imageEditMode = 'img';
+									else if ( this.imageElement.is( 'input' ) )
+										this.imageEditMode = 'input';
+								}
 							}
 						}
 						// Fill out all fields.
@@ -319,8 +353,7 @@
 
 						// Fill out all fields.
 						this.setupContent( IMAGE, this.imageElement );
-					} else
-						this.imageElement = editor.document.createElement( 'img' );
+					}
 
 					// Refresh LockRatio button
 					switchLockRatio( this, true );
@@ -337,7 +370,7 @@
 						var imgTagName = this.imageEditMode;
 
 						// Image dialog and Input element.
-						if ( dialogType == 'image' && imgTagName == 'input' && confirm( editor.lang.image.button2Img ) ) {
+						if ( dialogType == 'image' && imgTagName == 'input' && confirm( editor.lang.image.button2Img ) ) { // jshint ignore:line
 							// Replace INPUT-> IMG
 							imgTagName = 'img';
 							this.imageElement = editor.document.createElement( 'img' );
@@ -345,7 +378,7 @@
 							editor.insertElement( this.imageElement );
 						}
 						// ImageButton dialog and Image element.
-						else if ( dialogType != 'image' && imgTagName == 'img' && confirm( editor.lang.image.img2Button ) ) {
+						else if ( dialogType != 'image' && imgTagName == 'img' && confirm( editor.lang.image.img2Button ) ) { // jshint ignore:line
 							// Replace IMG -> INPUT
 							imgTagName = 'input';
 							this.imageElement = editor.document.createElement( 'input' );
@@ -359,8 +392,9 @@
 							this.imageElement = this.cleanImageElement;
 							delete this.cleanImageElement;
 						}
-					} else // Create a new image.
-					{
+					}
+					// Create a new image.
+					else {
 						// Image dialog -> create IMG element.
 						if ( dialogType == 'image' )
 							this.imageElement = editor.document.createElement( 'img' );
@@ -386,22 +420,33 @@
 					// Insert a new Image.
 					if ( !this.imageEditMode ) {
 						if ( this.addLink ) {
-							//Insert a new Link.
 							if ( !this.linkEditMode ) {
+								// Insert a new link.
 								editor.insertElement( this.linkElement );
 								this.linkElement.append( this.imageElement, false );
-							} else //Link already exists, image not.
+							} else {
+								// We already have a link in editor.
+								if ( this.linkElement.equals( editor.getSelection().getSelectedElement() ) ) {
+									// If the link is selected outside, replace it's content rather than the link itself. ([<a>foo</a>])
+									this.linkElement.setHtml( '' );
+									this.linkElement.append( this.imageElement, false );
+								} else {
+									// Only inside of the link is selected, so replace it with image. (<a>[foo]</a>, <a>[f]oo</a>)
+									editor.insertElement( this.imageElement );
+								}
+							}
+						} else {
 							editor.insertElement( this.imageElement );
-						} else
-							editor.insertElement( this.imageElement );
-					} else // Image already exists.
-					{
-						//Add a new link element.
+						}
+					}
+					// Image already exists.
+					else {
+						// Add a new link element.
 						if ( !this.linkEditMode && this.addLink ) {
 							editor.insertElement( this.linkElement );
 							this.imageElement.appendTo( this.linkElement );
 						}
-						//Remove Link, Image exists.
+						// Remove Link, Image exists.
 						else if ( this.linkEditMode && !this.addLink ) {
 							editor.getSelection().selectElement( this.linkElement );
 							editor.insertElement( this.imageElement );
@@ -434,22 +479,18 @@
 
 					delete this.imageElement;
 				},
-				contents: [
-					{
+				contents: [ {
 					id: 'info',
 					label: editor.lang.image.infoTab,
 					accessKey: 'I',
-					elements: [
-						{
+					elements: [ {
 						type: 'vbox',
 						padding: 0,
-						children: [
-							{
+						children: [ {
 							type: 'hbox',
 							widths: [ '280px', '110px' ],
 							align: 'right',
-							children: [
-								{
+							children: [ {
 								id: 'txtUrl',
 								type: 'text',
 								label: editor.lang.common.url,
@@ -458,16 +499,18 @@
 									var dialog = this.getDialog(),
 										newUrl = this.getValue();
 
-									//Update original image
-									if ( newUrl.length > 0 ) //Prevent from load before onShow
-									{
+									// Update original image.
+									// Prevent from load before onShow.
+									if ( newUrl.length > 0 ) {
 										dialog = this.getDialog();
 										var original = dialog.originalElement;
 
-										dialog.preview.removeStyle( 'display' );
+										if ( dialog.preview ) {
+											dialog.preview.removeStyle( 'display' );
+										}
 
 										original.setCustomData( 'isReady', 'false' );
-										// Show loader
+										// Show loader.
 										var loader = CKEDITOR.document.getById( imagePreviewLoaderId );
 										if ( loader )
 											loader.setStyle( 'display', '' );
@@ -477,10 +520,12 @@
 										original.on( 'abort', onImgLoadErrorEvent, dialog );
 										original.setAttribute( 'src', newUrl );
 
-										// Query the preloader to figure out the url impacted by based href.
-										previewPreloader.setAttribute( 'src', newUrl );
-										dialog.preview.setAttribute( 'src', previewPreloader.$.src );
-										updatePreview( dialog );
+										if ( dialog.preview ) {
+											// Query the preloader to figure out the url impacted by based href.
+											previewPreloader.setAttribute( 'src', newUrl );
+											dialog.preview.setAttribute( 'src', previewPreloader.$.src );
+											updatePreview( dialog );
+										}
 									}
 									// Dont show preview if no URL given.
 									else if ( dialog.preview ) {
@@ -511,7 +556,7 @@
 								},
 								validate: CKEDITOR.dialog.validate.notEmpty( editor.lang.image.urlMissing )
 							},
-								{
+							{
 								type: 'button',
 								id: 'browse',
 								// v-align with the 'txtUrl' field.
@@ -521,12 +566,10 @@
 								label: editor.lang.common.browseServer,
 								hidden: true,
 								filebrowser: 'info:txtUrl'
-							}
-							]
-						}
-						]
+							} ]
+						} ]
 					},
-						{
+					{
 						id: 'txtAlt',
 						type: 'text',
 						label: editor.lang.image.alt,
@@ -545,28 +588,25 @@
 									element.setAttribute( 'alt', this.getValue() );
 							} else if ( type == PREVIEW )
 								element.setAttribute( 'alt', this.getValue() );
-							else if ( type == CLEANUP )
+							else if ( type == CLEANUP ) {
 								element.removeAttribute( 'alt' );
+							}
 
 						}
 					},
-						{
+					{
 						type: 'hbox',
-						children: [
-							{
+						children: [ {
 							id: 'basic',
 							type: 'vbox',
-							children: [
-								{
+							children: [ {
 								type: 'hbox',
 								requiredContent: 'img{width,height}',
 								widths: [ '50%', '50%' ],
-								children: [
-									{
+								children: [ {
 									type: 'vbox',
 									padding: 1,
-									children: [
-										{
+									children: [ {
 										type: 'text',
 										width: '45px',
 										id: 'txtWidth',
@@ -579,11 +619,11 @@
 											var aMatch = this.getValue().match( regexGetSizeOrEmpty ),
 												isValid = !!( aMatch && parseInt( aMatch[ 1 ], 10 ) !== 0 );
 											if ( !isValid )
-												alert( editor.lang.common.invalidWidth );
+												alert( editor.lang.common.invalidWidth ); // jshint ignore:line
 											return isValid;
 										},
 										setup: setupDimension,
-										commit: function( type, element, internalCommit ) {
+										commit: function( type, element ) {
 											var value = this.getValue();
 											if ( type == IMAGE ) {
 												if ( value && editor.activeFilter.check( 'img{width,height}' ) )
@@ -591,22 +631,23 @@
 												else
 													element.removeStyle( 'width' );
 
-												!internalCommit && element.removeAttribute( 'width' );
+												element.removeAttribute( 'width' );
 											} else if ( type == PREVIEW ) {
 												var aMatch = value.match( regexGetSize );
 												if ( !aMatch ) {
 													var oImageOriginal = this.getDialog().originalElement;
 													if ( oImageOriginal.getCustomData( 'isReady' ) == 'true' )
 														element.setStyle( 'width', oImageOriginal.$.width + 'px' );
-												} else
+												} else {
 													element.setStyle( 'width', CKEDITOR.tools.cssLength( value ) );
+												}
 											} else if ( type == CLEANUP ) {
 												element.removeAttribute( 'width' );
 												element.removeStyle( 'width' );
 											}
 										}
 									},
-										{
+									{
 										type: 'text',
 										id: 'txtHeight',
 										width: '45px',
@@ -619,11 +660,11 @@
 											var aMatch = this.getValue().match( regexGetSizeOrEmpty ),
 												isValid = !!( aMatch && parseInt( aMatch[ 1 ], 10 ) !== 0 );
 											if ( !isValid )
-												alert( editor.lang.common.invalidHeight );
+												alert( editor.lang.common.invalidHeight ); // jshint ignore:line
 											return isValid;
 										},
 										setup: setupDimension,
-										commit: function( type, element, internalCommit ) {
+										commit: function( type, element ) {
 											var value = this.getValue();
 											if ( type == IMAGE ) {
 												if ( value && editor.activeFilter.check( 'img{width,height}' ) )
@@ -631,24 +672,24 @@
 												else
 													element.removeStyle( 'height' );
 
-												!internalCommit && element.removeAttribute( 'height' );
+												element.removeAttribute( 'height' );
 											} else if ( type == PREVIEW ) {
 												var aMatch = value.match( regexGetSize );
 												if ( !aMatch ) {
 													var oImageOriginal = this.getDialog().originalElement;
 													if ( oImageOriginal.getCustomData( 'isReady' ) == 'true' )
 														element.setStyle( 'height', oImageOriginal.$.height + 'px' );
-												} else
+												} else {
 													element.setStyle( 'height', CKEDITOR.tools.cssLength( value ) );
+												}
 											} else if ( type == CLEANUP ) {
 												element.removeAttribute( 'height' );
 												element.removeStyle( 'height' );
 											}
 										}
-									}
-									]
+									} ]
 								},
-									{
+								{
 									id: 'ratioLock',
 									type: 'html',
 									style: 'margin-top:30px;width:40px;height:40px;',
@@ -671,8 +712,9 @@
 										// Activate (Un)LockRatio button
 										if ( ratioButton ) {
 											ratioButton.on( 'click', function( evt ) {
-												var locked = switchLockRatio( this ),
-													oImageOriginal = this.originalElement,
+												switchLockRatio( this );
+
+												var oImageOriginal = this.originalElement,
 													width = this.getValueOf( 'info', 'txtWidth' );
 
 												if ( oImageOriginal.getCustomData( 'isReady' ) == 'true' && width ) {
@@ -698,14 +740,12 @@
 										'<a href="javascript:void(0)" tabindex="-1" title="' + editor.lang.image.resetSize +
 										'" class="cke_btn_reset" id="' + btnResetSizeId + '" role="button"><span class="cke_label">' + editor.lang.image.resetSize + '</span></a>' +
 										'</div>'
-								}
-								]
+								} ]
 							},
-								{
+							{
 								type: 'vbox',
 								padding: 1,
-								children: [
-									{
+								children: [ {
 									type: 'text',
 									id: 'txtBorder',
 									requiredContent: 'img{border-width}',
@@ -729,16 +769,17 @@
 											this.setValue( value );
 										}
 									},
-									commit: function( type, element, internalCommit ) {
+									commit: function( type, element ) {
 										var value = parseInt( this.getValue(), 10 );
 										if ( type == IMAGE || type == PREVIEW ) {
 											if ( !isNaN( value ) ) {
 												element.setStyle( 'border-width', CKEDITOR.tools.cssLength( value ) );
 												element.setStyle( 'border-style', 'solid' );
-											} else if ( !value && this.isChanged() )
+											} else if ( !value && this.isChanged() ) {
 												element.removeStyle( 'border' );
+											}
 
-											if ( !internalCommit && type == IMAGE )
+											if ( type == IMAGE )
 												element.removeAttribute( 'border' );
 										} else if ( type == CLEANUP ) {
 											element.removeAttribute( 'border' );
@@ -748,7 +789,7 @@
 										}
 									}
 								},
-									{
+								{
 									type: 'text',
 									id: 'txtHSpace',
 									requiredContent: 'img{margin-left,margin-right}',
@@ -779,7 +820,7 @@
 											this.setValue( value );
 										}
 									},
-									commit: function( type, element, internalCommit ) {
+									commit: function( type, element ) {
 										var value = parseInt( this.getValue(), 10 );
 										if ( type == IMAGE || type == PREVIEW ) {
 											if ( !isNaN( value ) ) {
@@ -790,7 +831,7 @@
 												element.removeStyle( 'margin-right' );
 											}
 
-											if ( !internalCommit && type == IMAGE )
+											if ( type == IMAGE )
 												element.removeAttribute( 'hspace' );
 										} else if ( type == CLEANUP ) {
 											element.removeAttribute( 'hspace' );
@@ -799,7 +840,7 @@
 										}
 									}
 								},
-									{
+								{
 									type: 'text',
 									id: 'txtVSpace',
 									requiredContent: 'img{margin-top,margin-bottom}',
@@ -829,7 +870,7 @@
 											this.setValue( value );
 										}
 									},
-									commit: function( type, element, internalCommit ) {
+									commit: function( type, element ) {
 										var value = parseInt( this.getValue(), 10 );
 										if ( type == IMAGE || type == PREVIEW ) {
 											if ( !isNaN( value ) ) {
@@ -840,7 +881,7 @@
 												element.removeStyle( 'margin-bottom' );
 											}
 
-											if ( !internalCommit && type == IMAGE )
+											if ( type == IMAGE )
 												element.removeAttribute( 'vspace' );
 										} else if ( type == CLEANUP ) {
 											element.removeAttribute( 'vspace' );
@@ -849,7 +890,7 @@
 										}
 									}
 								},
-									{
+								{
 									id: 'cmbAlign',
 									requiredContent: 'img{float}',
 									type: 'select',
@@ -889,7 +930,7 @@
 											this.setValue( value );
 										}
 									},
-									commit: function( type, element, internalCommit ) {
+									commit: function( type, element ) {
 										var value = this.getValue();
 										if ( type == IMAGE || type == PREVIEW ) {
 											if ( value )
@@ -897,7 +938,7 @@
 											else
 												element.removeStyle( 'float' );
 
-											if ( !internalCommit && type == IMAGE ) {
+											if ( type == IMAGE ) {
 												value = ( element.getAttribute( 'align' ) || '' ).toLowerCase();
 												switch ( value ) {
 													// we should remove it only if it matches "left" or "right",
@@ -907,20 +948,17 @@
 														element.removeAttribute( 'align' );
 												}
 											}
-										} else if ( type == CLEANUP )
+										} else if ( type == CLEANUP ) {
 											element.removeStyle( 'float' );
-
+										}
 									}
-								}
-								]
-							}
-							]
+								} ]
+							} ]
 						},
-							{
+						{
 							type: 'vbox',
 							height: '250px',
-							children: [
-								{
+							children: [ {
 								type: 'html',
 								id: 'htmlPreview',
 								style: 'width:95%;',
@@ -929,24 +967,22 @@
 									'<div class="ImagePreviewBox"><table><tr><td>' +
 										'<a href="javascript:void(0)" target="_blank" onclick="return false;" id="' + previewLinkId + '">' +
 										'<img id="' + previewImageId + '" alt="" /></a>' +
+									// jscs:disable maximumLineLength
 										( editor.config.image_previewText || 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. ' +
 											'Maecenas feugiat consequat diam. Maecenas metus. Vivamus diam purus, cursus a, commodo non, facilisis vitae, ' +
 											'nulla. Aenean dictum lacinia tortor. Nunc iaculis, nibh non iaculis aliquam, orci felis euismod neque, sed ornare massa mauris sed velit. Nulla pretium mi et risus. Fusce mi pede, tempor id, cursus ac, ullamcorper nec, enim. Sed tortor. Curabitur molestie. Duis velit augue, condimentum at, ultrices a, luctus ut, orci. Donec pellentesque egestas eros. Integer cursus, augue in cursus faucibus, eros pede bibendum sem, in tempus tellus justo quis ligula. Etiam eget tortor. Vestibulum rutrum, est ut placerat elementum, lectus nisl aliquam velit, tempor aliquam eros nunc nonummy metus. In eros metus, gravida a, gravida sed, lobortis id, turpis. Ut ultrices, ipsum at venenatis fringilla, sem nulla lacinia tellus, eget aliquet turpis mauris non enim. Nam turpis. Suspendisse lacinia. Curabitur ac tortor ut ipsum egestas elementum. Nunc imperdiet gravida mauris.' ) +
+									// jscs:enable maximumLineLength
 									'</td></tr></table></div></div>'
-								}
-							]
-						}
-						]
-					}
-					]
+							} ]
+						} ]
+					} ]
 				},
-					{
+				{
 					id: 'Link',
 					requiredContent: 'a[href]',
 					label: editor.lang.image.linkTab,
 					padding: 0,
-					elements: [
-						{
+					elements: [ {
 						id: 'txtUrl',
 						type: 'text',
 						label: editor.lang.common.url,
@@ -969,11 +1005,13 @@
 
 									if ( this.getValue() || !editor.config.image_removeLinkByEmptyURL )
 										this.getDialog().addLink = true;
+									else
+										this.getDialog().addLink = false;
 								}
 							}
 						}
 					},
-						{
+					{
 						type: 'button',
 						id: 'browse',
 						filebrowser: {
@@ -985,7 +1023,7 @@
 						hidden: true,
 						label: editor.lang.common.browseServer
 					},
-						{
+					{
 						id: 'cmbTarget',
 						type: 'select',
 						requiredContent: 'a[target]',
@@ -997,7 +1035,7 @@
 							[ editor.lang.common.targetTop, '_top' ],
 							[ editor.lang.common.targetSelf, '_self' ],
 							[ editor.lang.common.targetParent, '_parent' ]
-							],
+						],
 						setup: function( type, element ) {
 							if ( type == LINK )
 								this.setValue( element.getAttribute( 'target' ) || '' );
@@ -1008,40 +1046,35 @@
 									element.setAttribute( 'target', this.getValue() );
 							}
 						}
-					}
-					]
+					} ]
 				},
-					{
+				{
 					id: 'Upload',
 					hidden: true,
 					filebrowser: 'uploadButton',
 					label: editor.lang.image.upload,
-					elements: [
-						{
+					elements: [ {
 						type: 'file',
 						id: 'upload',
 						label: editor.lang.image.btnUpload,
 						style: 'height:40px',
 						size: 38
 					},
-						{
+					{
 						type: 'fileButton',
 						id: 'uploadButton',
 						filebrowser: 'info:txtUrl',
 						label: editor.lang.image.btnUpload,
 						'for': [ 'Upload', 'upload' ]
-					}
-					]
+					} ]
 				},
-					{
+				{
 					id: 'advanced',
 					label: editor.lang.common.advancedTab,
-					elements: [
-						{
+					elements: [ {
 						type: 'hbox',
 						widths: [ '50%', '25%', '25%' ],
-						children: [
-							{
+						children: [ {
 							type: 'text',
 							id: 'linkId',
 							requiredContent: 'img[id]',
@@ -1057,7 +1090,7 @@
 								}
 							}
 						},
-							{
+						{
 							id: 'cmbLangDir',
 							type: 'select',
 							requiredContent: 'img[dir]',
@@ -1068,7 +1101,7 @@
 								[ editor.lang.common.notSet, '' ],
 								[ editor.lang.common.langDirLtr, 'ltr' ],
 								[ editor.lang.common.langDirRtl, 'rtl' ]
-								],
+							],
 							setup: function( type, element ) {
 								if ( type == IMAGE )
 									this.setValue( element.getAttribute( 'dir' ) );
@@ -1080,7 +1113,7 @@
 								}
 							}
 						},
-							{
+						{
 							type: 'text',
 							id: 'txtLangCode',
 							requiredContent: 'img[lang]',
@@ -1096,10 +1129,9 @@
 										element.setAttribute( 'lang', this.getValue() );
 								}
 							}
-						}
-						]
+						} ]
 					},
-						{
+					{
 						type: 'text',
 						id: 'txtGenLongDescr',
 						requiredContent: 'img[longdesc]',
@@ -1115,11 +1147,10 @@
 							}
 						}
 					},
-						{
+					{
 						type: 'hbox',
 						widths: [ '50%', '50%' ],
-						children: [
-							{
+						children: [ {
 							type: 'text',
 							id: 'txtGenClass',
 							requiredContent: 'img(cke-xyz)', // Random text like 'xyz' will check if all are allowed.
@@ -1136,7 +1167,7 @@
 								}
 							}
 						},
-							{
+						{
 							type: 'text',
 							id: 'txtGenTitle',
 							requiredContent: 'img[title]',
@@ -1155,14 +1186,13 @@
 										element.setAttribute( 'title', this.getValue() );
 								} else if ( type == PREVIEW )
 									element.setAttribute( 'title', this.getValue() );
-								else if ( type == CLEANUP )
+								else if ( type == CLEANUP ) {
 									element.removeAttribute( 'title' );
-
+								}
 							}
-						}
-						]
+						} ]
 					},
-						{
+					{
 						type: 'text',
 						id: 'txtdlgGenStyle',
 						requiredContent: 'img{cke-xyz}', // Random text like 'xyz' will check if all are allowed.
@@ -1188,10 +1218,17 @@
 							}
 						},
 						onChange: function() {
-							commitInternally.call( this, [ 'info:cmbFloat', 'info:cmbAlign',
-								'info:txtVSpace', 'info:txtHSpace',
-								'info:txtBorder',
-								'info:txtWidth', 'info:txtHeight' ] );
+							commitInternally.call(
+								this, [
+									'info:cmbFloat',
+									'info:cmbAlign',
+									'info:txtVSpace',
+									'info:txtHSpace',
+									'info:txtBorder',
+									'info:txtWidth',
+									'info:txtHeight'
+								]
+							);
 							updatePreview( this );
 						},
 						commit: function( type, element ) {
@@ -1199,10 +1236,8 @@
 								element.setAttribute( 'style', this.getValue() );
 
 						}
-					}
-					]
-				}
-				]
+					} ]
+				} ]
 			};
 		};
 
