@@ -1,19 +1,19 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'image2', 'da', {
 	alt: 'Alternativ tekst',
 	btnUpload: 'Upload fil til serveren',
-	captioned: 'Captioned image', // MISSING
-	captionPlaceholder: 'Caption', // MISSING
+	captioned: 'Tekstet billede',
+	captionPlaceholder: 'Tekst',
 	infoTab: 'Generelt',
 	lockRatio: 'Lås størrelsesforhold',
 	menu: 'Egenskaber for billede',
-	pathName: 'image', // MISSING
-	pathNameCaption: 'caption', // MISSING
+	pathName: 'billede',
+	pathNameCaption: 'tekst',
 	resetSize: 'Nulstil størrelse',
-	resizer: 'Click and drag to resize', // MISSING
+	resizer: 'Klik og træk for at ændre størrelsen',
 	title: 'Egenskaber for billede',
 	uploadTab: 'Upload',
 	urlMissing: 'Kilde på billed-URL mangler'
