@@ -1,17 +1,17 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'image2', 'ru', {
 	alt: 'Альтернативный текст',
 	btnUpload: 'Загрузить на сервер',
-	captioned: 'Захваченное изображение',
+	captioned: 'Отображать название',
 	captionPlaceholder: 'Название',
 	infoTab: 'Данные об изображении',
 	lockRatio: 'Сохранять пропорции',
 	menu: 'Свойства изображения',
 	pathName: 'изображение',
-	pathNameCaption: 'захват',
+	pathNameCaption: 'название',
 	resetSize: 'Вернуть обычные размеры',
 	resizer: 'Нажмите и растяните',
 	title: 'Свойства изображения',
