@@ -1,12 +1,12 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'image2', 'uk', {
 	alt: 'Альтернативний текст',
 	btnUpload: 'Надіслати на сервер',
 	captioned: 'Підписане зображення',
-	captionPlaceholder: 'Caption', // MISSING
+	captionPlaceholder: 'Заголовок',
 	infoTab: 'Інформація про зображення',
 	lockRatio: 'Зберегти пропорції',
 	menu: 'Властивості зображення',
