@@ -1,9 +1,9 @@
 /**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
 CKEDITOR.plugins.setLang( 'language', 'de', {
-	button: 'Sprache stellen',
+	button: 'Sprache festlegen',
 	remove: 'Sprache entfernen'
 } );
