@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
@@ -8,7 +8,9 @@
 ( function() {
 	CKEDITOR.plugins.add( 'link', {
 		requires: 'dialog,fakeobjects',
-		lang: 'af,ar,bg,bn,bs,ca,cs,cy,da,de,el,en,en-au,en-ca,en-gb,eo,es,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+		// jscs:disable maximumLineLength
+		lang: 'af,ar,bg,bn,bs,ca,cs,cy,da,de,de-ch,el,en,en-au,en-ca,en-gb,eo,es,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+		// jscs:enable maximumLineLength
 		icons: 'anchor,anchor-rtl,link,unlink', // %REMOVE_LINE_CORE%
 		hidpi: true, // %REMOVE_LINE_CORE%
 		onLoad: function() {
@@ -98,8 +100,9 @@
 
 						// Pass the link to be selected along with event data.
 						evt.data.link = element;
-					} else if ( CKEDITOR.plugins.link.tryRestoreFakeAnchor( editor, element ) )
+					} else if ( CKEDITOR.plugins.link.tryRestoreFakeAnchor( editor, element ) ) {
 						evt.data.dialog = 'anchor';
+					}
 				}
 			}, null, null, 0 );
 
@@ -145,7 +148,7 @@
 
 			// If the "contextmenu" plugin is loaded, register the listeners.
 			if ( editor.contextMenu ) {
-				editor.contextMenu.addListener( function( element, selection ) {
+				editor.contextMenu.addListener( function( element ) {
 					if ( !element || element.isReadOnly() )
 						return null;
 
@@ -200,8 +203,8 @@
 	// Loads the parameters in a selected link to the link dialog fields.
 	var javascriptProtocolRegex = /^javascript:/,
 		emailRegex = /^mailto:([^?]+)(?:\?(.+))?$/,
-		emailSubjectRegex = /subject=([^;?:@&=$,\/]*)/,
-		emailBodyRegex = /body=([^;?:@&=$,\/]*)/,
+		emailSubjectRegex = /subject=([^;?:@&=$,\/]*)/i,
+		emailBodyRegex = /body=([^;?:@&=$,\/]*)/i,
 		anchorRegex = /^#(.*)$/,
 		urlRegex = /^((?:http|https|ftp|news):\/\/)?(.*)$/,
 		selectableTargets = /^(_(?:self|top|parent|blank))$/,
@@ -414,8 +417,11 @@
 
 		/**
 		 * Parses attributes of the link element and returns an object representing
-		 * the current state (data) of the link. This data format is accepted e.g. by
-		 * the Link dialog window and {@link #getLinkAttributes}.
+		 * the current state (data) of the link. This data format is a plain object accepted
+		 * e.g. by the Link dialog window and {@link #getLinkAttributes}.
+		 *
+		 * **Note:** Data model format produced by the parser must be compatible with the Link
+		 * plugin dialog because it is passed directly to {@link CKEDITOR.dialog#setupContent}.
 		 *
 		 * @since 4.4
 		 * @param {CKEDITOR.editor} editor
@@ -432,9 +438,12 @@
 			if ( ( javascriptMatch = href.match( javascriptProtocolRegex ) ) ) {
 				if ( emailProtection == 'encode' ) {
 					href = href.replace( encodedEmailLinkRegex, function( match, protectedAddress, rest ) {
+						// Without it 'undefined' is appended to e-mails without subject and body (#9192).
+						rest = rest || '';
+
 						return 'mailto:' +
 							String.fromCharCode.apply( String, protectedAddress.split( ',' ) ) +
-							( rest && unescapeSingleQuote( rest ) );
+							unescapeSingleQuote( rest );
 					} );
 				}
 				// Protected email link as function call.
@@ -540,9 +549,9 @@
 		},
 
 		/**
-		 * Converts link data into an object which consists of attributes to be set
-		 * (with their values) and an array of attributes to be removed. This method
-		 * can be used to synthesise or to update any link element with the given data.
+		 * Converts link data produced by {@link #parseLinkAttributes} into an object which consists
+		 * of attributes to be set (with their values) and an array of attributes to be removed.
+		 * This method can be used to compose or to update any link element with the given data.
 		 *
 		 * @since 4.4
 		 * @param {CKEDITOR.editor} editor
@@ -569,7 +578,7 @@
 			// Compose the URL.
 			switch ( data.type ) {
 				case 'url':
-					var protocol = ( data.url && data.url.protocol != undefined ) ? data.url.protocol : 'http://',
+					var protocol = ( data.url && data.url.protocol !== undefined ) ? data.url.protocol : 'http://',
 						url = ( data.url && CKEDITOR.tools.trim( data.url.url ) ) || '';
 
 					set[ 'data-cke-saved-href' ] = ( url.indexOf( '/' ) === 0 ) ? url : protocol + url;
@@ -601,15 +610,16 @@
 
 							if ( emailProtection == 'encode' ) {
 								linkHref = [
-									'javascript:void(location.href=\'mailto:\'+',
+									'javascript:void(location.href=\'mailto:\'+', // jshint ignore:line
 									protectEmailAddressAsEncodedString( address )
 								];
 								// parameters are optional.
 								argList && linkHref.push( '+\'', escapeSingleQuote( argList ), '\'' );
 
 								linkHref.push( ')' );
-							} else
+							} else {
 								linkHref = [ 'mailto:', address, argList ];
+							}
 
 							break;
 						default:
@@ -618,7 +628,7 @@
 							email.name = nameAndDomain[ 0 ];
 							email.domain = nameAndDomain[ 1 ];
 
-							linkHref = [ 'javascript:', protectEmailLinkAsFunction( editor, email ) ];
+							linkHref = [ 'javascript:', protectEmailLinkAsFunction( editor, email ) ]; // jshint ignore:line
 					}
 
 					set[ 'data-cke-saved-href' ] = linkHref.join( '' );
@@ -651,8 +661,9 @@
 					onclickList.push( featureList.join( ',' ), '\'); return false;' );
 					set[ 'data-cke-pa-onclick' ] = onclickList.join( '' );
 				}
-				else if ( data.target.type != 'notSet' && data.target.name )
+				else if ( data.target.type != 'notSet' && data.target.name ) {
 					set.target = data.target.name;
+				}
 			}
 
 			// Advanced attributes.
@@ -672,12 +683,15 @@
 			if ( set[ 'data-cke-saved-href' ] )
 				set.href = set[ 'data-cke-saved-href' ];
 
-			var removed = CKEDITOR.tools.extend( {
+			var removed = {
 				target: 1,
 				onclick: 1,
 				'data-cke-pa-onclick': 1,
 				'data-cke-saved-name': 1
-			}, advAttrNames );
+			};
+
+			if ( data.advanced )
+				CKEDITOR.tools.extend( removed, advAttrNames );
 
 			// Remove all attributes which are not currently set.
 			for ( var s in set )
@@ -729,8 +743,9 @@
 					if ( anchor.hasAttribute( 'href' ) ) {
 						anchor.removeAttributes( { name: 1, 'data-cke-saved-name': 1 } );
 						anchor.removeClass( 'cke_anchor' );
-					} else
+					} else {
 						anchor.remove( 1 );
+					}
 				}
 			}
 			sel.selectBookmarks( bms );
@@ -769,4 +784,4 @@
 		 * @member CKEDITOR.config
 		 */
 	} );
-} )();
\ No newline at end of file
+} )();
