@@ -1,8 +1,8 @@
 /**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
 CKEDITOR.plugins.setLang( 'magicline', 'ko', {
-	title: '여기에 그래프 삽입'
+	title: '여기에 단락 삽입'
 } );
