@@ -1,9 +1,9 @@
 /*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'mathjax', 'pt', {
-	title: 'Matemáticas em TeX',
+	title: 'Matemática em TeX',
 	button: 'Matemática',
 	dialogInput: 'Escreva aqui o seu Tex',
 	docUrl: 'http://en.wikibooks.org/wiki/LaTeX/Mathematics',
