@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'mathjax', 'sv', {
@@ -8,6 +8,6 @@ CKEDITOR.plugins.setLang( 'mathjax', 'sv', {
 	dialogInput: 'Skriv din TeX här',
 	docUrl: 'http://en.wikibooks.org/wiki/LaTeX/Mathematics',
 	docLabel: 'TeX dokumentation',
-	loading: 'laddar',
+	loading: 'laddar...',
 	pathName: 'matte'
 } );
