@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
@@ -8,7 +8,9 @@
  */
 
 CKEDITOR.plugins.add( 'print', {
-	lang: 'af,ar,bg,bn,bs,ca,cs,cy,da,de,el,en,en-au,en-ca,en-gb,eo,es,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+	// jscs:disable maximumLineLength
+	lang: 'af,ar,bg,bn,bs,ca,cs,cy,da,de,de-ch,el,en,en-au,en-ca,en-gb,eo,es,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+	// jscs:enable maximumLineLength
 	icons: 'print,', // %REMOVE_LINE_CORE%
 	hidpi: true, // %REMOVE_LINE_CORE%
 	init: function( editor ) {
@@ -19,7 +21,7 @@ CKEDITOR.plugins.add( 'print', {
 		var pluginName = 'print';
 
 		// Register the command.
-		var command = editor.addCommand( pluginName, CKEDITOR.plugins.print );
+		editor.addCommand( pluginName, CKEDITOR.plugins.print );
 
 		// Register the toolbar button.
 		editor.ui.addButton && editor.ui.addButton( 'Print', {
@@ -32,10 +34,11 @@ CKEDITOR.plugins.add( 'print', {
 
 CKEDITOR.plugins.print = {
 	exec: function( editor ) {
-		if ( CKEDITOR.env.gecko )
+		if ( CKEDITOR.env.gecko ) {
 			editor.window.$.print();
-		else
-			editor.document.$.execCommand( "Print" );
+		} else {
+			editor.document.$.execCommand( 'Print' );
+		}
 	},
 	canUndo: false,
 	readOnly: 1,
