@@ -1,9 +1,9 @@
-﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
 */
 CKEDITOR.plugins.setLang( 'smiley', 'de', {
-	options: 'Smiley Optionen',
+	options: 'Smiley-Optionen',
 	title: 'Smiley auswählen',
 	toolbar: 'Smiley'
 } );
