@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or http://ckeditor.com/license
  */
 
@@ -36,12 +36,13 @@
 
 					// Make the first button focus accessible for IE. (#3417)
 					// Adobe AIR instead need while of delay.
-					if ( CKEDITOR.env.ie || CKEDITOR.env.air )
+					if ( CKEDITOR.env.ie || CKEDITOR.env.air ) {
 						setTimeout( function() {
+							editor.toolbox.focus();
+						}, 100 );
+					} else {
 						editor.toolbox.focus();
-					}, 100 );
-					else
-						editor.toolbox.focus();
+					}
 				}
 			}
 		}
@@ -49,7 +50,9 @@
 
 	CKEDITOR.plugins.add( 'toolbar', {
 		requires: 'button',
-		lang: 'af,ar,bg,bn,bs,ca,cs,cy,da,de,el,en,en-au,en-ca,en-gb,eo,es,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+		// jscs:disable maximumLineLength
+		lang: 'af,ar,bg,bn,bs,ca,cs,cy,da,de,de-ch,el,en,en-au,en-ca,en-gb,eo,es,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+		// jscs:enable maximumLineLength
 
 		init: function( editor ) {
 			var endFlag;
@@ -70,7 +73,11 @@
 							// Cycle through the toolbars, starting from the one
 							// closest to the current item.
 							while ( !toolbar || !toolbar.items.length ) {
-								toolbar = keystroke == 9 ? ( ( toolbar ? toolbar.next : item.toolbar.next ) || editor.toolbox.toolbars[ 0 ] ) : ( ( toolbar ? toolbar.previous : item.toolbar.previous ) || editor.toolbox.toolbars[ editor.toolbox.toolbars.length - 1 ] );
+								if ( keystroke == 9 ) {
+									toolbar = ( ( toolbar ? toolbar.next : item.toolbar.next ) || editor.toolbox.toolbars[ 0 ] );
+								} else {
+									toolbar = ( ( toolbar ? toolbar.previous : item.toolbar.previous ) || editor.toolbox.toolbars[ editor.toolbox.toolbars.length - 1 ] );
+								}
 
 								// Look for the first item that accepts focus.
 								if ( toolbar.items.length ) {
@@ -171,7 +178,8 @@
 
 				var output = [
 					'<span id="', labelId, '" class="cke_voice_label">', editor.lang.toolbar.toolbars, '</span>',
-					'<span id="' + editor.ui.spaceId( 'toolbox' ) + '" class="cke_toolbox" role="group" aria-labelledby="', labelId, '" onmousedown="return false;">' ];
+					'<span id="' + editor.ui.spaceId( 'toolbox' ) + '" class="cke_toolbox" role="group" aria-labelledby="', labelId, '" onmousedown="return false;">'
+				];
 
 				var expanded = editor.config.toolbarStartupExpanded !== false,
 					groupStarted, pendingSeparator;
@@ -264,7 +272,7 @@
 								groupStarted = 0;
 							}
 
-							function addItem( item ) {
+							function addItem( item ) { // jshint ignore:line
 								var itemObj = item.render( editor, output );
 								index = toolbarObj.items.push( itemObj ) - 1;
 
@@ -345,7 +353,11 @@
 							var dy = toolboxContainer.$.offsetHeight - previousHeight;
 							contents.setStyle( 'height', ( contentHeight - dy ) + 'px' );
 
-							editor.fire( 'resize' );
+							editor.fire( 'resize', {
+								outerHeight: editor.container.$.offsetHeight,
+								contentsHeight: contents.$.offsetHeight,
+								outerWidth: editor.container.$.offsetWidth
+							} );
 						},
 
 						modes: { wysiwyg: 1, source: 1 }
@@ -353,9 +365,9 @@
 
 					editor.setKeystroke( CKEDITOR.ALT + ( CKEDITOR.env.ie || CKEDITOR.env.webkit ? 189 : 109 ) /*-*/, 'toolbarCollapse' );
 
-					output.push( '<a title="' + ( expanded ? editor.lang.toolbar.toolbarCollapse : editor.lang.toolbar.toolbarExpand )
-						+ '" id="' + editor.ui.spaceId( 'toolbar_collapser' )
-						+ '" tabIndex="-1" class="cke_toolbox_collapser' );
+					output.push( '<a title="' + ( expanded ? editor.lang.toolbar.toolbarCollapse : editor.lang.toolbar.toolbarExpand ) +
+						'" id="' + editor.ui.spaceId( 'toolbar_collapser' ) +
+						'" tabIndex="-1" class="cke_toolbox_collapser' );
 
 					if ( !expanded )
 						output.push( ' cke_toolbox_collapser_min' );
@@ -369,9 +381,7 @@
 			} );
 
 			editor.on( 'destroy', function() {
-
-				if ( this.toolbox )
-				{
+				if ( this.toolbox ) {
 					var toolbars,
 						index = 0,
 						i, items, instance;
@@ -620,7 +630,7 @@
 
 	function getPrivateToolbarGroups( editor ) {
 		return editor._.toolbarGroups || ( editor._.toolbarGroups = [
-			{ name: 'document',	   groups: [ 'mode', 'document', 'doctools' ] },
+			{ name: 'document',    groups: [ 'mode', 'document', 'doctools' ] },
 			{ name: 'clipboard',   groups: [ 'clipboard', 'undo' ] },
 			{ name: 'editing',     groups: [ 'find', 'selection', 'spellchecker' ] },
 			{ name: 'forms' },
@@ -656,6 +666,9 @@ CKEDITOR.UI_SEPARATOR = 'separator';
  * (`iframe`-based) editor. In case of [inline](#!/guide/dev_inline) editor the toolbar
  * position is set dynamically depending on the position of the editable element on the screen.
  *
+ * Read more in the [documentation](#!/guide/dev_toolbarlocation)
+ * and see the [SDK sample](http://sdk.ckeditor.com/samples/toolbarlocation.html).
+ *
  *		config.toolbarLocation = 'bottom';
  *
  * @cfg
@@ -670,6 +683,9 @@ CKEDITOR.config.toolbarLocation = 'top';
  * If set to `null`, the toolbar will be generated automatically using all available buttons
  * and {@link #toolbarGroups} as a toolbar groups layout.
  *
+ * In CKEditor 4.5+ you can generate your toolbar customization code by using the [visual
+ * toolbar configurator](http://docs.ckeditor.com/#!/guide/dev_toolbar).
+ *
  *		// Defines a toolbar with only one strip containing the "Source" button, a
  *		// separator, and the "Bold" and "Italic" buttons.
  *		config.toolbar = [
