@@ -1,20 +1,21 @@
-/* bender-tags: editor,unit */
+/* bender-tags: editor,unit,jquery */
 /* bender-ckeditor-plugins: wysiwygarea */
+/* global $ */
 
 CKEDITOR.replaceClass = 'ckeditor';
 CKEDITOR.disableAutoInline = false;
 
-var passed = false, onLoaded;
+var passed = false,
+	onLoaded;
 
-CKEDITOR.on( 'instanceCreated', function( evt ) {
+CKEDITOR.on( 'instanceCreated', function() {
 	passed = !onLoaded;
 } );
 
 $( window ).on( 'load', function() {
-	onLoaded =1;
+	onLoaded = 1;
 
-	bender.test(
-	{
+	bender.test( {
 		'check instances are created before "onload" event': function() {
 			if ( CKEDITOR.env.ie && ( document.documentMode || CKEDITOR.env.version ) < 9 )
 				assert.ignore();
@@ -25,4 +26,4 @@ $( window ).on( 'load', function() {
 } );
 
 // Large image to delay the page loading.
-document.write( '<img src="%BASE_PATH%_assets/large.jpg' + '?'+ encodeURI( new Date().getTime() ) + '" />' );
\ No newline at end of file
+document.write( '<img src="%BASE_PATH%_assets/large.jpg' + '?' + encodeURI( new Date().getTime() ) + '" />' );
\ No newline at end of file
