@@ -1,4 +1,5 @@
 /* bender-tags: editor,unit,dom */
+/* global appendDomObjectTests */
 
 var getInnerHtml = bender.tools.getInnerHtml,
 	getOuterHtml = function( element ) {
@@ -14,40 +15,40 @@ bender.test( appendDomObjectTests(
 		return new CKEDITOR.dom.element( document.getElementById( id ) );
 	},
 	{
-		test_$ : function() {
+		test_$: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			assert.areSame( document.getElementById( 'test1' ), element.$ );
 		},
 
-		test_getId1 : function() {
+		test_getId1: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			assert.areEqual( 'test1', element.getId() );
 		},
 
-		test_getId2 : function() {
+		test_getId2: function() {
 			// Used body to ommit head element when searching, because YUI add div to it.
 			// See http://yuilibrary.com/forum-archive/forum/viewtopic.php@f=18&t=12285.html
 			var element = newElement( document.body.getElementsByTagName( 'div' )[ 0 ] );
 			assert.isNull( element.getId() );
 		},
 
-		test_getNameAtt1 : function() {
+		test_getNameAtt1: function() {
 			var element = newElement( document.getElementsByName( 'named1' )[ 0 ] );
 			assert.areEqual( 'named1', element.getNameAtt() );
 		},
 
-		test_getNameAtt2 : function() {
+		test_getNameAtt2: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			assert.isNull( element.getNameAtt() );
 		},
 
-		test_getName : function() {
+		test_getName: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			assert.areEqual( 'textarea', element.getName(), 'First call' );
 			assert.areEqual( 'textarea', element.getName(), 'Second call' );
 		},
 
-		test_hide : function() {
+		test_hide: function() {
 			var nativeElement = document.getElementById( 'test1' );
 			nativeElement.style.display = '';
 
@@ -57,7 +58,7 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( 'none', nativeElement.style.display );
 		},
 
-		test_show : function() {
+		test_show: function() {
 			var nativeElement = document.getElementById( 'test1' );
 			nativeElement.style.display = '';
 
@@ -67,13 +68,13 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( '', nativeElement.style.display );
 		},
 
-		test_createFromHtml : function() {
+		test_createFromHtml: function() {
 			var element = CKEDITOR.dom.element.createFromHtml( '<p>My test</p>' );
 			assert.areEqual( 'p', element.getName(), 'element name doesn\'t match' );
 			assert.areEqual( 'My test', element.$.innerHTML, 'the innerHTML doesn\'t match' );
 		},
 
-		test_createFromHtml2 : function() {
+		test_createFromHtml2: function() {
 			var element = CKEDITOR.dom.element.createFromHtml( '<div><x:x><p>Test</p></div>' );
 			assert.areNotEqual( 'Test', element.getChild( 0, 0 ).innerHTML );
 		},
@@ -83,32 +84,63 @@ bender.test( appendDomObjectTests(
 			assert.areSame( 'figure', element.getName( 'figure' ) );
 		},
 
-		test_append1 : function() {
+		'test getChild - single index': function() {
+			var element = CKEDITOR.dom.element.createFromHtml( '<ul><li>zero</li><li>one</li></ul>' );
+
+			assert.areSame( 'zero', element.getChild( 0 ).getHtml() );
+			assert.areSame( 'one', element.getChild( 1 ).getHtml() );
+		},
+
+		'test getChild - array selector': function() {
+			var element = CKEDITOR.dom.element.createFromHtml( '<div><ul><li>zero</li><li>one</li></ul></div>' );
+
+			assert.areSame( 'ul', element.getChild( [ 0 ] ).getName() );
+			assert.areSame( 'one', element.getChild( [ 0, 1 ] ).getHtml() );
+			assert.isNull( element.getChild( [ 0, 2 ] ) );
+			assert.isNull( element.getChild( [ 1, 0 ] ) );
+		},
+
+		'test getChild does not modify array': function() {
+			var selector = [ 1, 0 ],
+				element = CKEDITOR.dom.element.createFromHtml( '<div><ul><li>zero</li><li>one</li></ul></div>' );
+
+			element.getChild( selector );
+			assert.areSame( 2, selector.length );
+		},
+
+		test_append1: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			element.append( newElement( 'b' ) );
 			assert.areEqual( 'b', document.getElementById( 'append' ).firstChild.nodeName.toLowerCase() );
 		},
 
-		test_append2 : function() {
+		test_append2: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			element.append( 'i' );
 			assert.areEqual( 'i', document.getElementById( 'append' ).lastChild.nodeName.toLowerCase() );
 		},
 
-		test_appendText1 : function() {
+		test_appendText1: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			element.setHtml( '' );
 			element.appendText( 'Test appendText' );
 			assert.areEqual( 'Test appendText', document.getElementById( 'append' ).innerHTML );
 		},
 
-		test_appendText2 : function() {
+		test_appendText2: function() {
 			var element = newElement( 'script' );
 			element.appendText( 'Test appendText' );
 			assert.areEqual( 'Test appendText', element.$.text );
 		},
 
-		test_setHtml : function() {
+		// #13232
+		'test appendText to link': function() {
+			var element = newElement( 'a' );
+			element.appendText( '@' );
+			assert.areEqual( '@', element.getText() );
+		},
+
+		test_setHtml: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			element.setHtml( '<b>Test</b>' );
 			assert.areEqual( '<b>test</b>', document.getElementById( 'append' ).innerHTML.toLowerCase(), 'First call doesn\'t match' );
@@ -123,74 +155,75 @@ bender.test( appendDomObjectTests(
 			assert.isMatching( /^<figure>foo<\/figure>$/i, element.getHtml() );
 		},
 
-		test_getDocument1 : function() {
+		test_getDocument1: function() {
 			var element = newElement( 'div' );
 			assert.areSame( document, element.getDocument().$, 'First call' );
 			assert.areSame( document, element.getDocument().$, 'Second call' );
 		},
 
-		test_getDocument2 : function() {
+		test_getDocument2: function() {
 			var element = newElement( document.body );
 			assert.areSame( document, element.getDocument().$, 'First call' );
 			assert.areSame( document, element.getDocument().$, 'Second call' );
 		},
 
-		test_getFirst1 : function() {
+		test_getFirst1: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			element.setHtml( '<b>Test</b>' );
 			var first = element.getFirst();
 			assert.areSame( 'b', first.getName() );
 		},
 
-		test_getFirst2 : function() {
+		test_getFirst2: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			element.setHtml( 'Test' );
 			var first = element.getFirst();
 			assert.areSame( 'Test', first.$.nodeValue );
 		},
 
-		test_getFirst3 : function() {
+		test_getFirst3: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			element.setHtml( '' );
 			var first = element.getFirst();
 			assert.isNull( first );
 		},
 
-		test_setAttribute1 : function() {
+		test_setAttribute1: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			element.setAttribute( 'class', 'Test' );
 
 			assert.areSame( 'Test', document.getElementById( 'test1' ).className );
 		},
 
-		test_setAttribute2 : function() {
+		test_setAttribute2: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			element.setAttribute( 'style', 'position: absolute;' );
 
 			assert.areEqual( 'position: absolute;', bender.tools.getAttribute( element, 'style' ) );
 		},
 
-		test_setAttribute3 : function() {
+		test_setAttribute3: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			element.setAttribute( 'name', 'TestName' );
 
 			assert.areEqual( 'TestName', document.getElementById( 'test1' ).name );
 		},
 
-		test_setAttribute4 : function() {
+		test_setAttribute4: function() {
 			var element = newElement( document.getElementById( 'test1' ) );
 			element.setAttribute( 'rows', 5 );
 
 			assert.areEqual( 5, document.getElementById( 'test1' ).rows );
 		},
 
-		test_setAttributes : function() {
+		test_setAttributes: function() {
 			var element = newElement( document.getElementById( 'test2' ) );
 			element.setAttributes( {
-				'class'	: 'Test',
-				'style'	: 'position: absolute;',
-				'name'	: 'TestName',
-				'rows'	: 5 } );
+				'class': 'Test',
+				style: 'position: absolute;',
+				name: 'TestName',
+				rows: 5
+			} );
 
 			assert.areSame( 'Test', document.getElementById( 'test1' ).className, 'class is wrong' );
 			assert.areEqual( 'position: absolute;', bender.tools.getAttribute( element, 'style' ), 'style is wrong' );
@@ -198,14 +231,14 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( 5, document.getElementById( 'test1' ).rows, 'rows is wrong' );
 		},
 
-		test_setStyle1 : function() {
+		test_setStyle1: function() {
 			var element = newElement( document.getElementById( 'setStyle' ) );
 			element.setStyle( 'position', 'absolute' );
 
 			assert.areEqual( 'absolute', document.getElementById( 'setStyle' ).style.position );
 		},
 
-		test_setStyle2 : function() {
+		test_setStyle2: function() {
 			var element = newElement( document.getElementById( 'setStyle' ) );
 			element.setStyle( 'float', 'right' );
 
@@ -216,43 +249,43 @@ bender.test( appendDomObjectTests(
 			assert.areSame( 'float', div.getAttribute( 'style' ).split( ':' )[ 0 ].toLowerCase() );
 		},
 
-		test_setStyles : function() {
+		test_setStyles: function() {
 			var element = newElement( document.getElementById( 'setStyle' ) );
 			element.setStyles( {
-					'position' : 'absolute',
-					'float' : 'right'
-				} );
+				position: 'absolute',
+				'float': 'right'
+			} );
 
 			assert.areEqual( 'absolute', document.getElementById( 'setStyle' ).style.position );
 			assert.areEqual( 'right', element.getStyle( 'float' ) );
 		},
 
-		test_setText1 : function() {
+		test_setText1: function() {
 			var element = newElement( document.getElementById( 'setText' ) );
 			element.setText( 'A & B' );
 			assert.areSame( 'A &amp; B', document.getElementById( 'setText' ).innerHTML );
 		},
 
-		test_setText2 : function() {
+		test_setText2: function() {
 			var element = newElement( document.getElementById( 'setText' ) );
 			element.setText( 'C & D' );
 			assert.areSame( 'C &amp; D', document.getElementById( 'setText' ).innerHTML );
 		},
 
-		test_addClass1 : function() {
+		'test addClass - basic case': function() {
 			var element = newElement( 'div' );
 			element.addClass( 'classA' );
 			assert.areSame( 'classA', element.$.className );
 		},
 
-		test_addClass2 : function() {
+		'test addClass2 - one class added twice': function() {
 			var element = newElement( 'div' );
 			element.addClass( 'classA' );
 			element.addClass( 'classA' );
 			assert.areSame( 'classA', element.$.className );
 		},
 
-		test_addClass3 : function() {
+		'test addClass - multiple classes': function() {
 			var element = newElement( 'div' );
 			element.addClass( 'classA' );
 			element.addClass( 'classB' );
@@ -260,7 +293,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( 'classA classB classC', element.$.className );
 		},
 
-		test_addClass4 : function() {
+		'test addClass - multiple classes, multiple duplicates': function() {
 			var element = newElement( 'div' );
 			element.addClass( 'classA' );
 			element.addClass( 'classB' );
@@ -271,7 +304,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( 'classA classB classC', element.$.className );
 		},
 
-		test_removeClass1 : function() {
+		'test removeClass - basic case': function() {
 			document.getElementById( 'removeClass' ).innerHTML = '';
 
 			var element = CKEDITOR.dom.element.createFromHtml( '<div class="classA"></div>' );
@@ -282,7 +315,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( '<div></div>', getInnerHtml( 'removeClass' ) );
 		},
 
-		test_removeClass2 : function() {
+		'test removeClass - multiple classes': function() {
 			document.getElementById( 'removeClass' ).innerHTML = '';
 
 			var element = CKEDITOR.dom.element.createFromHtml( '<div class="classA classB classC classD"></div>' );
@@ -299,7 +332,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( '<div></div>', getInnerHtml( 'removeClass' ) );
 		},
 
-		test_removeClass3 : function() {
+		'test removeClass - case insensitive, non existing classes': function() {
 			document.getElementById( 'removeClass' ).innerHTML = '';
 
 			var element = CKEDITOR.dom.element.createFromHtml( '<div class="classA classB"></div>' );
@@ -314,7 +347,35 @@ bender.test( appendDomObjectTests(
 			assert.areSame( '<div class="classa"></div>', getInnerHtml( 'removeClass' ) );
 		},
 
-		test_removeAttribute1 : function() {
+		'test hasClass - parsed element': function() {
+			var element = CKEDITOR.dom.element.createFromHtml( '<div class=" classA\t classB \nclassC\t"></div>' );
+
+			assert.isTrue( element.hasClass( 'classA' ), 'classA' );
+			assert.isTrue( element.hasClass( 'classB' ), 'classB' );
+			assert.isTrue( element.hasClass( 'classC' ), 'classC' );
+			assert.isFalse( element.hasClass( 'class' ), 'class' );
+		},
+
+		'test hasClass - after addClass/removeClass': function() {
+			var element = newElement( 'div' );
+
+			assert.isFalse( element.hasClass( 'classA' ), 'before' );
+
+			element.addClass( 'classA' );
+			assert.isTrue( element.hasClass( 'classA' ), 'after added' );
+
+			element.removeClass( 'classA' );
+			assert.isFalse( element.hasClass( 'classA' ), 'after removed' );
+		},
+
+		'test hasClass - case sensitive': function() {
+			var element = CKEDITOR.dom.element.createFromHtml( '<div class="classA"></div>' );
+
+			assert.isFalse( element.hasClass( 'classa' ), 'classa' );
+			assert.isFalse( element.hasClass( 'Classa' ), 'classa' );
+		},
+
+		test_removeAttribute1: function() {
 			document.getElementById( 'removeClass' ).innerHTML = '';
 
 			var element = CKEDITOR.dom.element.createFromHtml( '<div class="classA"></div>' );
@@ -324,7 +385,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( '<div></div>', getInnerHtml( 'removeClass' ) );
 		},
 
-		test_removeAttribute2 : function() {
+		test_removeAttribute2: function() {
 			document.getElementById( 'removeClass' ).innerHTML = '';
 
 			var element = CKEDITOR.dom.element.createFromHtml( '<div style="position:absolute"></div>' );
@@ -334,7 +395,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( '<div></div>', getInnerHtml( 'removeClass' ) );
 		},
 
-		test_removeAttribute3 : function() {
+		test_removeAttribute3: function() {
 			document.getElementById( 'removeClass' ).innerHTML = '';
 
 			var element = CKEDITOR.dom.element.createFromHtml( '<div title="Test"></div>' );
@@ -344,42 +405,40 @@ bender.test( appendDomObjectTests(
 			assert.areSame( '<div></div>', getInnerHtml( 'removeClass' ) );
 		},
 
-		test_remove : function() {
+		test_remove: function() {
 			var element = newElement( document.getElementById( 'removeInner' ) );
 			element.remove();
 
 			assert.areSame( '', getInnerHtml( 'removeOuter' ) );
 		},
 
-		test_getAttribute_tabindex1 : function() {
+		test_getAttribute_tabindex1: function() {
 			var element = newElement( document.getElementById( 'tabIndex10' ) );
 			assert.areEqual( 10, bender.tools.getAttribute( element, 'tabindex' ) );
 		},
 
-		test_getAttribute_tabindex2 : function() {
+		test_getAttribute_tabindex2: function() {
 			var element = newElement( document.getElementById( 'tabIndexDef' ) );
 			assert.isNull( bender.tools.getAttribute( element, 'tabindex' ) );
 		},
 
-		test_getAttribute_tabindex3 : function() {
+		test_getAttribute_tabindex3: function() {
 			var element = newElement( document.getElementById( 'tabIndexInputDef' ) );
 			assert.isNull( bender.tools.getAttribute( element, 'tabindex' ) );
 		},
 
-		test_getAttribute_tabindex4 : function() {
+		test_getAttribute_tabindex4: function() {
 			var element = newElement( document.getElementById( 'tabIndexInput20' ) );
 			assert.areEqual( 20, bender.tools.getAttribute( element, 'tabindex' ) );
 		},
 
-		test_getAttribute_tabindex5 : function() {
+		test_getAttribute_tabindex5: function() {
 			var element = newElement( document.getElementById( 'tabIndexScriptDef' ) );
 			assert.areEqual( null, bender.tools.getAttribute( element, 'tabindex' ) );
 		},
 
-		/**
-		 * Test set and retrieve 'checked' attribute value. (#4527)
-		 */
-		test_getAttribute_checked : function() {
+		// Test set and retrieve 'checked' attribute value. (#4527)
+		test_getAttribute_checked: function() {
 			var unchecked1 = new CKEDITOR.dom.element.createFromHtml( '<input type="checkbox" />' ),
 				checked1 = new CKEDITOR.dom.element.createFromHtml( '<input type="checkbox" checked="checked" />' ),
 				checked2 = new CKEDITOR.dom.element( 'input' );
@@ -391,7 +450,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( 'checked', checked2.getAttribute( 'checked' ) );
 		},
 
-		test_getAttribute_contenteditable : function() {
+		test_getAttribute_contenteditable: function() {
 			var body = CKEDITOR.document.getBody();
 			var element = body.append( CKEDITOR.dom.element.createFromHtml( '<div contenteditable="true"></div>' ) );
 			assert.areEqual( 'true', element.getAttribute( 'contenteditable' ) );
@@ -401,10 +460,8 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( null, element.getAttribute( 'contenteditable' ) );
 		},
 
-		/**
-		 *  Test getAttribute and getAttribute will ingore  '_cke_expando' attribute.
-		 */
-		/*test_getAttribute_ignoreExpandoAttributes : function()
+		//  Test getAttribute and getAttribute will ingore  '_cke_expando' attribute.
+		/*test_getAttribute_ignoreExpandoAttributes: function()
 		{
 			var element = newElement( document.getElementById( 'testExpandoAttributes' ) );
 
@@ -421,67 +478,67 @@ bender.test( appendDomObjectTests(
 			assert.isFalse( element.hasAttributes(), 'hasAttributes should be false' );
 		},*/
 
-		test_getTabIndex1 : function() {
+		test_getTabIndex1: function() {
 			var element = newElement( document.getElementById( 'tabIndex10' ) );
 			assert.areSame( 10, element.getTabIndex() );
 		},
 
-		test_getTabIndex2 : function() {
+		test_getTabIndex2: function() {
 			var element = newElement( document.getElementById( 'tabIndexDef' ) );
 			assert.areSame( -1, element.getTabIndex() );
 		},
 
-		test_getTabIndex3 : function() {
+		test_getTabIndex3: function() {
 			var element = newElement( document.getElementById( 'tabIndexInputDef' ) );
 			assert.areSame( 0, element.getTabIndex() );
 		},
 
-		test_getTabIndex4 : function() {
+		test_getTabIndex4: function() {
 			var element = newElement( document.getElementById( 'tabIndexInput20' ) );
 			assert.areSame( 20, element.getTabIndex() );
 		},
 
-		test_getTabIndex5 : function() {
+		test_getTabIndex5: function() {
 			var element = newElement( document.getElementById( 'tabIndexScriptDef' ) );
 			assert.areSame( -1, element.getTabIndex() );
 		},
 
-		test_getText1 : function() {
+		test_getText1: function() {
 			var element = newElement( document.getElementById( 'getText' ) );
 
 			// IE gives us a different result, which is ok for us (see code comments).
-			if ( CKEDITOR.env.ie && !( document.documentMode > 8 ) )
+			if ( CKEDITOR.env.ie && document.documentMode <= 8 )
 				assert.areSame( 'Some \nsample text for testing', element.getText().replace( /\r\n|\r/g, '\n' ) );
 			else
 				assert.areSame( 'Some  sample text    for    testing', element.getText() );
 		},
 
-		test_getText2 : function() {
+		test_getText2: function() {
 			var element = newElement( document.getElementById( 'getText2' ).getElementsByTagName( 'b' )[ 0 ] );
 			assert.areSame( ' ', element.getText() );
 		},
 
-		test_getText3 : function() {
+		test_getText3: function() {
 			var element = newElement( document.getElementById( 'getText3' ) );
 
 			// IE gives us a different result, which is ok for us (see code comments).
-			if ( CKEDITOR.env.ie && !( document.documentMode > 8 ) )
+			if ( CKEDITOR.env.ie && document.documentMode <= 8 )
 				assert.areSame( 'A B', element.getText() );
 			else
 				assert.areSame( 'A\nB', element.getText().replace( /\r\n|\r/g, '\n' ) );
 		},
 
-		test_hasAttributes1 : function() {
+		test_hasAttributes1: function() {
 			var element = newElement( document.getElementsByTagName( 'big' )[ 0 ] );
 			assert.isFalse( element.hasAttributes() );
 		},
 
-		test_hasAttributes2 : function() {
+		test_hasAttributes2: function() {
 			var element = newElement( document.getElementsByTagName( 'small' )[ 0 ] );
 			assert.isTrue( element.hasAttributes() );
 		},
 
-		test_hasAttribute : function() {
+		test_hasAttribute: function() {
 			var td = newElement( document.getElementById( 'td1' ) );
 
 			assert.isTrue( td.hasAttribute( 'id' ), 'id' );
@@ -497,7 +554,7 @@ bender.test( appendDomObjectTests(
 		// Test for 2 IE bugs:
 		// - value attribute is never specified even if it exists.
 		// - input attributes needs to be checked different way than other attributes.
-		test_hasAttribute_input : function() {
+		test_hasAttribute_input: function() {
 			var inputWithAttrs = newElement( document.getElementById( 'inputWithAttrs' ) ),
 				inputWithoutAttrs = newElement( document.getElementById( 'inputWithoutAttrs' ) ),
 				checkboxWithAttrs = newElement( document.getElementById( 'checkboxWithAttrs' ) ),
@@ -519,25 +576,38 @@ bender.test( appendDomObjectTests(
 		},
 
 
-		test_getDocumentPosition : function() {
-			// Assign the page location of the element.
-			YUI().use( 'dom-screen', 'node', function( Y ) {
-				resume( function() {
-					Y.one( '#DocPositionTarget' ).setXY( [ 350, 450 ] );
-					var pos = CKEDITOR.document.getById( 'DocPositionTarget' ).getDocumentPosition(),
-						x = Math.round( pos.x ),
-						y = Math.round( pos.y );
+		test_getDocumentPosition: function() {
+			var pos = CKEDITOR.document.getById( 'DocPositionTarget' ).getDocumentPosition(),
+				x = Math.round( pos.x ),
+				y = Math.round( pos.y ),
+				delta = 1,
+				expectedX = 280,
+				expectedY = 95;
 
-					assert.areEqual( 350, x, 'Position coordinates:x relative to document doesn\'t match.' );
-					assert.areEqual( 450, y, 'Position coordinates:y relative to document doesn\'t match.' );
-				} );
-			} );
+			assert.isNumberInRange( x, expectedX - delta, expectedX + delta, 'Position relative to document doesn\'t match ' + x + ' with offset ' + delta + '.' );
+			assert.isNumberInRange( y, expectedY - delta, expectedY + delta, 'Position relative to document doesn\'t match ' + y + 'with offset ' + delta + '.' );
+		},
 
-			wait();
+		'test getDocumentPosition with document scrolled': function() {
+			var scrolledElement = CKEDITOR.document.findOne( '#scrolled' );
+
+			// Scroll the window.
+			scrolledElement.focus();
+
+			var scrolledElementPosition = scrolledElement.getDocumentPosition();
+
+			assert.isNumberInRange(
+				scrolledElementPosition.x, 3498, 3502,
+				'Horizontal position read correctly.'
+			);
+			assert.isNumberInRange(
+				scrolledElementPosition.y, 2998, 3002,
+				'Vertical position read correctly.'
+			);
 		},
 
 		// Test get last non-spaces child node.
-		test_getLast : function() {
+		test_getLast: function() {
 			var element = newElement( document.getElementById( 'append' ) );
 			var span1 = newElement( 'span' );
 			element.append( span1 );
@@ -548,13 +618,13 @@ bender.test( appendDomObjectTests(
 		},
 
 		// Test 'display:none' and 'visibity:hidden' elements.
-		test_invisible : function() {
+		test_invisible: function() {
 			assert.isFalse( doc.getById( 'invisible1' ).isVisible() );
 			assert.isFalse( doc.getById( 'invisible2' ).isVisible() );
 		},
 
 		// #7070
-		test_getBogus : function() {
+		test_getBogus: function() {
 			// Test padding block bogus BR for non-IEs.
 			if ( CKEDITOR.env.ie )
 				assert.ignore();
@@ -567,7 +637,7 @@ bender.test( appendDomObjectTests(
 			assert.isTrue( !!doc.getById( 'bogus_tc5' ).getBogus() );
 		},
 
-		test_appendHtml : function() {
+		test_appendHtml: function() {
 			var element = doc.getById( 'appendHtml' );
 
 			element.appendHtml( '<i>text</i>test' );
@@ -575,16 +645,16 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( '<div id="appendhtml"><i>text</i>test</div>', getOuterHtml( element ) );
 		},
 
-		test_breakParent : function() {
+		test_breakParent: function() {
 			var parent = doc.getById( 'breakParent' ).getFirst(),
 				element = parent.getFirst().getNext();
 
 			element.breakParent( parent );
 
-			assert.areEqual( '<i>text1</i><b>text2</b><i>text3</i>', getInnerHtml( 'breakParent' ) );
+			assert.areEqual( '<i id="a">text1</i><b id="b">text2</b><i>text3</i>', getInnerHtml( 'breakParent' ) );
 		},
 
-		test_contains : function() {
+		test_contains: function() {
 			var body = CKEDITOR.document.getBody(),
 				parent = doc.getById( 'contains' ),
 				el = doc.getById( 'contains1' ),
@@ -603,18 +673,18 @@ bender.test( appendDomObjectTests(
 			assert.isTrue( body.contains( el2.getFirst() ) );
 		},
 
-		test_getChildren : function() {
+		test_getChildren: function() {
 			var element = doc.getById( 'getChildren' );
 			assert.areEqual( 3, element.getChildren().count() );
 		},
 
-		test_getComputedStyle : function() {
+		test_getComputedStyle: function() {
 			var element = doc.getById( 'getChildren' );
 			assert.areEqual( 'block', element.getComputedStyle( 'display' ) );
 			assert.areEqual( 'inline', element.getFirst().getComputedStyle( 'display' ) );
 		},
 
-		test_getElementsByTag : function() {
+		test_getElementsByTag: function() {
 			var element = doc.getById( 'getChildren' ),
 				elements = element.getElementsByTag( 'b' );
 
@@ -622,7 +692,7 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( 'b', elements.getItem( 0 ).getName() );
 		},
 
-		test_isIdentical : function() {
+		test_isIdentical: function() {
 				// <b name="a" class="test">tessst</b>
 			var element1 = doc.getById( 'isIdentical' ).getFirst(),
 				// <b class="test" name="a"></b>
@@ -657,7 +727,7 @@ bender.test( appendDomObjectTests(
 			}
 		},
 
-		test_isIdentical2 : function() {
+		test_isIdentical2: function() {
 				// <b style="color: red; width: 10px">a</b>
 			var element1 = doc.getById( 'isIdentical2' ).getFirst(),
 				// <b style="width:10px;color:red;">a</b>
@@ -678,7 +748,7 @@ bender.test( appendDomObjectTests(
 			assert.isFalse( element3.isIdentical( element4 ), 'different styles' );
 		},
 
-		'test isIdentical ignore child nodes' : function() {
+		'test isIdentical ignore child nodes': function() {
 			var el1 = CKEDITOR.dom.element.createFromHtml( '<b class="foo" style="color: red; width: 10px">foo</b>' ),
 				el2 = el1.clone();
 
@@ -687,7 +757,7 @@ bender.test( appendDomObjectTests(
 			assert.isTrue( el1.isIdentical( el2 ) );
 		},
 
-		test_isEmptyInlineRemoveable : function() {
+		test_isEmptyInlineRemoveable: function() {
 			var element1 = doc.getById( 'isEmptyInlineRemoveable' ).getFirst(),
 				element2 = element1.getNext(),
 				element3 = element2.getNext();
@@ -697,7 +767,7 @@ bender.test( appendDomObjectTests(
 			assert.isFalse( element3.isEmptyInlineRemoveable() );
 		},
 
-		test_moveChildren : function() {
+		test_moveChildren: function() {
 			var element1 = doc.getById( 'moveChildren1' ),
 				element2 = doc.getById( 'moveChildren2' );
 
@@ -706,14 +776,14 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( 2, element2.getChildren().count() );
 		},
 
-		test_mergeSiblings : function() {
+		test_mergeSiblings: function() {
 			var element = doc.getById( 'mergeSiblings' ).getFirst();
 
 			element.mergeSiblings( false );
 			assert.areEqual( '<b>text1text2</b>', bender.tools.fixHtml( doc.getById( 'mergeSiblings' ).getHtml() ) );
 		},
 
-		test_removeAttributes : function() {
+		test_removeAttributes: function() {
 			var element = doc.getById( 'removeAttributes' );
 
 			element.removeAttributes( [ 'id', 'class' ] );
@@ -723,7 +793,7 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( 'test2', element.getAttribute( 'title' ) );
 		},
 
-		test_removeStyle : function() {
+		test_removeStyle: function() {
 			var element = doc.getById( 'removeStyle' );
 
 			element.removeStyle( 'display' );
@@ -737,19 +807,19 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( '', element.getStyle( 'color' ) );
 		},
 
-		test_getPositionedAncestor : function() {
+		test_getPositionedAncestor: function() {
 			var element = doc.getById( 'getPositionedAncestor' );
 
 			assert.areEqual( element.getParent().getParent(), element.getPositionedAncestor() );
 		},
 
-		test_getFrameDocument : function() {
+		test_getFrameDocument: function() {
 			var frame = doc.getById( 'getFrameDocument' );
 
 			assert.isTrue( frame.getFrameDocument() instanceof CKEDITOR.dom.document );
 		},
 
-		test_copyAttributes : function() {
+		test_copyAttributes: function() {
 			var element1 = doc.getById( 'copyAttributes1' ),
 				element2 = doc.getById( 'copyAttributes2' );
 
@@ -762,7 +832,7 @@ bender.test( appendDomObjectTests(
 		// Because on IE td element contains colspan and rowspan attributes
 		// even if they are not defined explicit we need to test if copyAttributes
 		// check if attribute is specified properly.
-		test_copyAttributes_td : function() {
+		test_copyAttributes_td: function() {
 			var td1 = doc.getById( 'td1' ),
 				td2 = doc.getById( 'td2' );
 
@@ -775,7 +845,7 @@ bender.test( appendDomObjectTests(
 		/**
 		 * Test copy the 'checked' attribute. (#4527)
 		 */
-		test_copyAttributes_checked : function() {
+		test_copyAttributes_checked: function() {
 			var original1 = new CKEDITOR.dom.element.createFromHtml( '<input type="checkbox" checked="checked" />' ),
 				original2 = new CKEDITOR.dom.element( 'input' ),
 				clone1 = new CKEDITOR.dom.element( 'input' ),
@@ -789,7 +859,7 @@ bender.test( appendDomObjectTests(
 			assert.areSame( 'checked', clone2.getAttribute( 'checked' ) );
 		},
 
-		test_renameNode : function() {
+		test_renameNode: function() {
 			var element = doc.getById( 'renameNode' );
 
 			element.renameNode( 'p' );
@@ -801,7 +871,7 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( 2, element.getChildCount() );
 		},
 
-		test_renameNode_8663 : function() {
+		test_renameNode_8663: function() {
 			var element = doc.getById( 'renameNode2' );
 
 			assert.areEqual( 'div', element.getName(), 'Before rename' );
@@ -809,11 +879,22 @@ bender.test( appendDomObjectTests(
 			assert.areEqual( 'p', element.getName(), 'After rename' );
 		},
 
-		test_getDirection : function() {
+		test_renameNode_in_documentFragment: function() {
+			var frag = new CKEDITOR.dom.documentFragment(),
+				inner = new CKEDITOR.dom.element( 'div' );
+
+			frag.append( inner );
+
+			assert.areEqual( 'div', frag.getChild( 0 ).getName(), 'Before rename' );
+			inner.renameNode( 'p' );
+			assert.areEqual( 'p', frag.getChild( 0 ).getName(), 'After rename' );
+		},
+
+		test_getDirection: function() {
 			assert.areEqual( 'rtl', doc.getById( 'getDirection' ).getDirection() );
 		},
 
-		test_data : function() {
+		test_data: function() {
 			var element = doc.getById( 'data' );
 			assert.areEqual( 'testing', element.data( 'test' ) );
 			element.data( 'test', false );
@@ -821,7 +902,7 @@ bender.test( appendDomObjectTests(
 		},
 
 		// Test when element to compare has more attributes .
-		test_element_identical : function() {
+		test_element_identical: function() {
 			var element1 = CKEDITOR.dom.element.createFromHtml( '<span class="foo"></span>' ),
 				element2 = CKEDITOR.dom.element.createFromHtml( '<span class="foo"></span>' );
 
@@ -829,14 +910,14 @@ bender.test( appendDomObjectTests(
 		},
 
 		// #8527
-		'test empty anchor editable' : function() {
+		'test empty anchor editable': function() {
 			assert.isFalse( doc.getById( 'empty_anchor_1' ).isEditable() );
 			assert.isFalse( doc.getById( 'empty_anchor_2' ).isEditable() );
 			assert.isTrue( doc.getById( 'text_anchor_1' ).isEditable() );
 			assert.isTrue( doc.getById( 'text_anchor_2' ).isEditable() );
 		},
 
-		test_is : function() {
+		test_is: function() {
 			var element = newElement( 'p' );
 
 			assert.isTrue( element.is( 'p' ) );
@@ -877,7 +958,7 @@ bender.test( appendDomObjectTests(
 			assert.isInstanceOf( CKEDITOR.dom.element, found );
 			assert.areSame( 'X', found.getHtml() );
 
-			var found = el.findOne( '.findRoot .findRoot' );
+			found = el.findOne( '.findRoot .findRoot' );
 
 			assert.isNull( found, 'Selector is contextualized' );
 		},
@@ -896,8 +977,9 @@ bender.test( appendDomObjectTests(
 						text = CKEDITOR.tools.trim( node.getText() );
 						if ( text )
 							tokens.push( '#' + text );
-					} else
+					} else {
 						tokens.push( 'not implemented type' );
+					}
 
 					if ( callback )
 						return callback( node );
@@ -947,5 +1029,53 @@ bender.test( appendDomObjectTests(
 			el.forEach( recorder.fn, CKEDITOR.NODE_ELEMENT, true );
 			assert.areSame( 'p,i,div,h1,h2,b', recorder.tokens.join( ',' ) );
 		},
+
+		'test disableContextMenu - element with cke_enable_context_menu class': function() {
+			var target = doc.getById( 'disableContextMenu_1' ),
+				preventDefaultCalled = 0;
+
+			target.disableContextMenu();
+
+			target.fire( 'contextmenu', new CKEDITOR.dom.event( {
+				target: target.$,
+				preventDefault: function() {
+					++preventDefaultCalled;
+				}
+			} ) );
+
+			assert.areSame( 0, preventDefaultCalled, 'preventDefault was not called' );
+		},
+
+		'test disableContextMenu - ancestor with cke_enable_context_menu class': function() {
+			var target = doc.getById( 'disableContextMenu_2' ),
+				preventDefaultCalled = 0;
+
+			target.disableContextMenu();
+
+			target.fire( 'contextmenu', new CKEDITOR.dom.event( {
+				target: target.$,
+				preventDefault: function() {
+					++preventDefaultCalled;
+				}
+			} ) );
+
+			assert.areSame( 0, preventDefaultCalled, 'preventDefault was not called' );
+		},
+
+		'test disableContextMenu': function() {
+			var target = doc.getById( 'disableContextMenu_3' ),
+				preventDefaultCalled = 0;
+
+			target.disableContextMenu();
+
+			target.fire( 'contextmenu', new CKEDITOR.dom.event( {
+				target: target.$,
+				preventDefault: function() {
+					++preventDefaultCalled;
+				}
+			} ) );
+
+			assert.areSame( 1, preventDefaultCalled, 'preventDefault was called' );
+		}
 	}
 ) );
\ No newline at end of file
