@@ -1,4 +1,5 @@
 /* bender-tags: editor,unit,insertion */
+/* global insertionDT */
 
 ( function() {
 	'use strict';
@@ -6,7 +7,7 @@
 	insertionDT.run( {
 		enterMode: CKEDITOR.MODE_BR,
 		autoParagraph: false,
-		allowedContent : true // Disable filter.
+		allowedContent: true
 	}, {
 		'insert block between &lt;brs&gt;': function() {
 			var a = this.createAssertInsertionFunction( 'body,div', '<h1>abc</h1>', 'html' );
