@@ -3,9 +3,8 @@
 
 CKEDITOR.replaceClass = 'ckeditor';
 
-bender.test(
-{
-	'test auto initilization' : function() {
+bender.test( {
+	'test auto initilization': function() {
 		CKEDITOR.on( 'instanceReady', function( evt ) {
 			if ( evt.editor.name == 'editor1' ) {
 				resume( function() {
@@ -17,8 +16,8 @@ bender.test(
 		wait();
 	},
 
-	'test replace' : function() {
-		CKEDITOR.replace( 'editor2', { on : {
+	'test replace': function() {
+		CKEDITOR.replace( 'editor2', { on: {
 			instanceReady: function( evt ) {
 				resume( function() {
 					assert.areEqual( '<p>ed2</p>', bender.tools.compatHtml( evt.editor.getData() ) );
