@@ -3,6 +3,9 @@
 
 'use strict';
 
+var fillingCharSequence = CKEDITOR.dom.selection.FILLING_CHAR_SEQUENCE,
+	fillingCharSequenceLength = fillingCharSequence.length;
+
 function noSelectionOnBlur( editor ) {
 	return editor.elementMode == CKEDITOR.ELEMENT_MODE_INLINE || CKEDITOR.env.ie;
 }
@@ -18,7 +21,8 @@ bender.editors = {
 		config: {
 			autoParagraph: false,
 			fillEmptyBlocks: false,
-			allowedContent: true
+			allowedContent: true,
+			plugins: 'undo'
 		}
 	},
 	editorInline: {
@@ -53,7 +57,7 @@ bender.test( {
 		var fillingChar = editable.getCustomData( 'cke-fillingChar' );
 		assert.isTrue( !!fillingChar, 'Filling char exists - ' + msg );
 		assert.areSame( parent, fillingChar.getParent(), 'Filling char parent - ' + msg );
-		assert.areSame( contents, fillingChar.getText(), 'Filling char contents - ' + msg );
+		assert.areSame( fillingCharSequence + contents, fillingChar.getText(), 'Filling char contents - ' + msg );
 
 		return fillingChar;
 	},
@@ -381,6 +385,25 @@ bender.test( {
 		wait();
 	},
 
+	// #13816
+	'test remove filling character from snapshots and data': function() {
+		if ( !CKEDITOR.env.webkit )
+			assert.ignore();
+
+		var editor = this.editors.editor,
+			bot = this.editorBots.editor;
+
+		bot.setData( '<p>foo</p>', function() {
+			var fc = new CKEDITOR.dom.text( fillingCharSequence );
+
+			fc.appendTo( editor.document.findOne( 'p' ), 1 );
+
+			assert.areSame( '<p>' + fillingCharSequence + 'foo</p>', editor.editable().getHtml(), 'FC in DOM.' );
+			assert.areSame( '<p>foo</p>', new CKEDITOR.plugins.undo.Image( editor ).contents, 'No FC in snapshots.' );
+			assert.areSame( '<p>foo</p>', editor.getData(), 'No FC in data.' );
+		} );
+	},
+
 	// #10315
 	'test selection is invalidating filling char after editable is replaced by new one': function() {
 		if ( !CKEDITOR.env.webkit )
@@ -405,7 +428,7 @@ bender.test( {
 						range.setStart( editor.document.getById( 'p' ), 1 );
 						editor.getSelection().selectRanges( [ range ] );
 
-						assert.isMatching( /^<p id="p">foo\u200b<em>bar<\/em><\/p>$/, editor.editable().getHtml(), 'Filling char was inserted' );
+						assert.isMatching( '^<p id="p">foo' + fillingCharSequence + '<em>bar<\/em><\/p>$', editor.editable().getHtml(), 'Filling char was inserted' );
 
 						// Fire event imitating left arrow, what will trigger
 						// removeFillingChar() on Webkit.
@@ -420,27 +443,16 @@ bender.test( {
 						range.setStart( editor.document.getById( 'p' ), 1 );
 						editor.getSelection().selectRanges( [ range ] );
 
-						assert.isMatching( /^<p id="p">foo\u200b<em>bar<\/em><\/p>$/, editor.editable().getHtml(), 'Filling char was inserted 2' );
-
-						editor.dataProcessor = {
-							toHtml: function( html ) {
-								return html;
-							},
-							toDataFormat: function( html ) {
-								return html;
-							}
-						};
-
+						assert.isMatching( '^<p id="p">foo' + fillingCharSequence + '<em>bar<\/em><\/p>$', editor.editable().getHtml(), 'Filling char was inserted 2' );
 						assert.isMatching( /^<p id="p">foo<em>bar<\/em><\/p>$/, editor.getData(), 'Filling char was removed on getData' );
 
-
 						// TC3 - on undo image
 						// <p>foo^<em>...
 						range = editor.createRange();
 						range.setStart( editor.document.getById( 'p' ), 1 );
 						editor.getSelection().selectRanges( [ range ] );
 
-						assert.isMatching( /^<p id="p">foo\u200b<em>bar<\/em><\/p>$/, editor.editable().getHtml(), 'Filling char was inserted 2' );
+						assert.isMatching( '^<p id="p">foo' + fillingCharSequence + '<em>bar<\/em><\/p>$', editor.editable().getHtml(), 'Filling char was inserted 2' );
 
 						assert.isMatching( /^<p id="p">foo<em>bar<\/em><\/p>$/, new CKEDITOR.plugins.undo.Image( editor ).contents, 'Filling char was removed on beforeUndoImage' );
 					} );
@@ -451,32 +463,33 @@ bender.test( {
 		} );
 	},
 
-	'test filling char is removed and restored when taking snapshot': function() {
+	'test filling char remains untouched when taking snapshot': function() {
 		if ( !CKEDITOR.env.webkit )
 			assert.ignore();
 
 		var editor = this.editors.editor,
 			editable = editor.editable(),
-			range = editor.createRange();
+			range;
 
 		this.setSelectionInEmptyInlineElement( editor );
 
 		var uEl = editable.findOne( 'u' ),
-			fillingChar = this.assertFillingChar( editable, uEl, '\u200b', 'after set selection' );
+			fillingChar = this.assertFillingChar( editable, uEl, '', 'after set selection' );
 
 		editor.fire( 'beforeUndoImage' );
 		this.assertFillingChar( editable, uEl, '', 'after beforeUndoImage' );
 
 		editor.fire( 'afterUndoImage' );
-		fillingChar = this.assertFillingChar( editable, uEl, '\u200b', 'after afterUndoImage' );
+		fillingChar = this.assertFillingChar( editable, uEl, '', 'after afterUndoImage' );
 
 		range = editor.getSelection().getRanges()[ 0 ];
-		assert.areSame( fillingChar, range.startContainer, 'Selection was restored - container' );
-		assert.areSame( 1, range.startOffset, 'Selection was restored - offset after ZWS' );
+		range.optimize();
+		assert.areSame( fillingChar.getParent(), range.startContainer, 'Selection remains - container' );
+		assert.areSame( 1, range.startOffset, 'Selection remains - offset after FC' );
 	},
 
 	// #12489
-	'test filling char is removed and restored when taking snapshot if selection is not right after the filling char': function() {
+	'test filling char remains when taking snapshot if selection is not right after the filling char': function() {
 		if ( !CKEDITOR.env.webkit )
 			assert.ignore();
 
@@ -487,24 +500,24 @@ bender.test( {
 		this.setSelectionInEmptyInlineElement( editor );
 
 		var uEl = editable.findOne( 'u' ),
-			fillingChar = this.assertFillingChar( editable, uEl, '\u200b', 'after set selection' );
+			fillingChar = this.assertFillingChar( editable, uEl, '', 'after set selection' );
 
 		// Happens when typing and navigating...
 		// Setting selection using native API to avoid losing the filling char on selection.setRanges().
 		fillingChar.setText( fillingChar.getText() + 'abcd' );
-		editor.document.$.getSelection().setPosition( fillingChar.$, 3 ); // ZWSab^cd
+		editor.document.$.getSelection().setPosition( fillingChar.$, fillingChar.$.nodeValue.length - 2 ); // FCab^cd
 
-		this.assertFillingChar( editable, uEl, '\u200babcd', 'after type' );
+		this.assertFillingChar( editable, uEl, 'abcd', 'after type' );
 
 		editor.fire( 'beforeUndoImage' );
 		this.assertFillingChar( editable, uEl, 'abcd', 'after beforeUndoImage' );
 
 		editor.fire( 'afterUndoImage' );
-		fillingChar = this.assertFillingChar( editable, uEl, '\u200babcd', 'after afterUndoImage' );
+		fillingChar = this.assertFillingChar( editable, uEl, 'abcd', 'after afterUndoImage' );
 
 		range = editor.getSelection().getRanges()[ 0 ];
-		assert.areSame( fillingChar, range.startContainer, 'Selection was restored - container' );
-		assert.areSame( 3, range.startOffset, 'Selection was restored - offset in ZWSab^cd' );
+		assert.areSame( fillingChar, range.startContainer, 'Selection remains - container' );
+		assert.areSame( fillingCharSequenceLength + 2, range.startOffset, 'Selection remains - offset in FCab^cd' );
 	},
 
 	// #8617
@@ -519,14 +532,14 @@ bender.test( {
 		this.setSelectionInEmptyInlineElement( editor );
 
 		var uEl = editable.findOne( 'u' ),
-			fillingChar = this.assertFillingChar( editable, uEl, '\u200b', 'after setting selection' );
+			fillingChar = this.assertFillingChar( editable, uEl, '', 'after setting selection' );
 
 		// Happens when typing and navigating...
 		// Setting selection using native API to avoid losing the filling char on selection.setRanges().
 		fillingChar.setText( fillingChar.getText() + 'abc' );
-		editor.document.$.getSelection().setPosition( fillingChar.$, 4 ); // ZWSabc^
+		editor.document.$.getSelection().setPosition( fillingChar.$, fillingChar.$.nodeValue.length ); // FCabc^
 
-		this.assertFillingChar( editable, uEl, '\u200babc', 'after typing' );
+		this.assertFillingChar( editable, uEl, 'abc', 'after typing' );
 
 		// Mock LEFT arrow.
 		editor.document.fire( 'keydown', new CKEDITOR.dom.event( { keyCode: 37 } ) );
@@ -550,14 +563,14 @@ bender.test( {
 		this.setSelectionInEmptyInlineElement( editor );
 
 		var uEl = editable.findOne( 'u' ),
-			fillingChar = this.assertFillingChar( editable, uEl, '\u200b', 'after setting selection' );
+			fillingChar = this.assertFillingChar( editable, uEl, '', 'after setting selection' );
 
 		// Happens when typing and navigating...
 		// Setting selection using native API to avoid losing the filling char on selection.setRanges().
 		fillingChar.setText( fillingChar.getText() + 'abc' );
-		editor.document.$.getSelection().setPosition( fillingChar.$, 4 ); // ZWSabc^
+		editor.document.$.getSelection().setPosition( fillingChar.$, fillingChar.$.nodeValue.length ); // FCabc^
 
-		this.assertFillingChar( editable, uEl, '\u200babc', 'after typing' );
+		this.assertFillingChar( editable, uEl, 'abc', 'after typing' );
 
 		// Select all contents.
 		range.selectNodeContents( editable.findOne( 'p' ) );
@@ -579,21 +592,21 @@ bender.test( {
 		this.setSelectionInEmptyInlineElement( editor );
 
 		var uEl = editable.findOne( 'u' ),
-			fillingChar = this.assertFillingChar( editable, uEl, '\u200b', 'after setting selection' );
+			fillingChar = this.assertFillingChar( editable, uEl, '', 'after setting selection' );
 
 		// Happens when typing and making selection from right to left...
 		// Setting selection using native API to avoid losing the filling char on selection.setRanges().
 		fillingChar.setText( fillingChar.getText() + 'abc' );
 		range = editor.document.$.createRange();
-		// ZWSabc]
-		range.setStart( fillingChar.$, 4 );
+		// FCabc]
+		range.setStart( fillingChar.$, fillingChar.$.nodeValue.length );
 		var nativeSel = editor.document.$.getSelection();
 		nativeSel.removeAllRanges();
 		nativeSel.addRange( range );
-		// ZWSa[bc
-		nativeSel.extend( fillingChar.$, 2 );
+		// FCa[bc
+		nativeSel.extend( fillingChar.$, fillingChar.$.nodeValue.length - 2 );
 
-		this.assertFillingChar( editable, uEl, '\u200babc', 'after typing' );
+		this.assertFillingChar( editable, uEl, 'abc', 'after typing' );
 
 		// Mock LEFT arrow.
 		editor.document.fire( 'keydown', new CKEDITOR.dom.event( { keyCode: 37 } ) );
@@ -619,31 +632,31 @@ bender.test( {
 		this.setSelectionInEmptyInlineElement( editor );
 
 		var uEl = editable.findOne( 'u' ),
-			fillingChar = this.assertFillingChar( editable, uEl, '\u200b', 'after set selection' );
+			fillingChar = this.assertFillingChar( editable, uEl, '', 'after set selection' );
 
 		// Happens when typing and making selection from right to left...
 		// Setting selection using native API to avoid losing the filling char on selection.setRanges().
 		fillingChar.setText( fillingChar.getText() + 'abc' );
 		range = editor.document.$.createRange();
-		// ZWSabc]
-		range.setStart( fillingChar.$, 4 );
+		// FCabc]
+		range.setStart( fillingChar.$, fillingChar.$.nodeValue.length );
 		var nativeSel = editor.document.$.getSelection();
 		nativeSel.removeAllRanges();
 		nativeSel.addRange( range );
-		// ZWSa[bc
-		nativeSel.extend( fillingChar.$, 2 );
+		// FCa[bc
+		nativeSel.extend( fillingChar.$, fillingChar.$.nodeValue.length - 2 );
 
-		this.assertFillingChar( editable, uEl, '\u200babc', 'after type' );
+		this.assertFillingChar( editable, uEl, 'abc', 'after type' );
 
 		editor.fire( 'beforeUndoImage' );
 		this.assertFillingChar( editable, uEl, 'abc', 'after beforeUndoImage' );
 
 		editor.fire( 'afterUndoImage' );
-		this.assertFillingChar( editable, uEl, '\u200babc', 'after afterUndoImage' );
+		this.assertFillingChar( editable, uEl, 'abc', 'after afterUndoImage' );
 
 		nativeSel = editor.document.$.getSelection();
-		assert.areSame( 4, nativeSel.anchorOffset, 'sel.anchorOffset' );
-		assert.areSame( 2, nativeSel.focusOffset, 'sel.focusOffset' );
+		assert.areSame( fillingCharSequenceLength + 3, nativeSel.anchorOffset, 'sel.anchorOffset' );
+		assert.areSame( fillingCharSequenceLength + 1, nativeSel.focusOffset, 'sel.focusOffset' );
 	},
 
 	'test selection in source mode': function() {
