@@ -40,15 +40,17 @@ function createTestKeyNavFn( editor, target ) {
 		bspc: 8
 	};
 
+	var prevented = false;
+
 	return function( key, rangeOrEl, pos, msg ) {
 		var range;
 
 		if ( !( rangeOrEl instanceof CKEDITOR.dom.range ) ) {
 			range = editor.createRange();
 			range.moveToPosition( rangeOrEl, pos );
-		}
-		else
+		} else {
 			range = rangeOrEl;
+		}
 
 		editor.getSelection().selectRanges( [ range ] );
 
@@ -56,9 +58,8 @@ function createTestKeyNavFn( editor, target ) {
 		editor.editable().fire( 'keydown', getKeyEvent( keyCodes[ key ], preventDefaultCallback ) );
 		assert.areSame( target, editor.getSelection().getSelectedElement(), msg );
 		assert[ target ? 'isTrue' : 'isFalse' ]( prevented, msg + ' - prevented' );
-	}
+	};
 
-	var prevented = false;
 	function preventDefaultCallback() {
 		prevented = true;
 	}
@@ -162,7 +163,7 @@ bender.test( {
 			var selectionChange = 0,
 				selectedRanges;
 
-			var listener = editor.on( 'selectionChange', function( evt ) {
+			editor.on( 'selectionChange', function( evt ) {
 				selectionChange++;
 				selectedRanges = evt.data.selection.getRanges();
 			} );
@@ -265,6 +266,22 @@ bender.test( {
 		assert.isTrue( editor.getSelection( 1 ).isHidden(), 'Real selection is placed in hidden element' );
 	},
 
+	'Fake-selection bookmark mark as not faked when no enclosed node found. (#13280)': function() {
+		bender.tools.selection.setWithHtml( this.editor, '<p>fo{o ba}r</p>' );
+
+		var sel = this.editor.getSelection(),
+			bookmarks = sel.createBookmarks2(),
+			selectRangesSpy = sinon.spy( sel, 'selectRanges' ),
+			warnStub = sinon.stub( CKEDITOR, 'warn' );
+
+		bookmarks.isFake = 1;
+		sel.selectBookmarks( bookmarks );
+		warnStub.restore();
+
+		assert.isTrue( selectRangesSpy.calledOnce );
+		assert.isFalse( !!sel.isFake, 'isFake is reset' );
+	},
+
 	'Fake-selection bookmark (serializable)': function() {
 		var editor = this.editor;
 
@@ -700,7 +717,7 @@ bender.test( {
 	'Test moving to sibling non-editable blocks by arrow keys': function() {
 		var editor = this.editor;
 
-		this.editorBot.setData( '<p id="p1" contenteditable="false">X</p><p id="p2" contenteditable="false">X</p><p id="p3" contenteditable="false">X</p>', function() {
+		this.editorBot.setData( '<p>X</p><p id="p1" contenteditable="false">X</p><p id="p2" contenteditable="false">X</p><p id="p3" contenteditable="false">X</p>', function() {
 			var p1 = editor.document.getById( 'p1' ),
 				p2 = editor.document.getById( 'p2' ),
 				p3 = editor.document.getById( 'p3' ),
@@ -727,10 +744,6 @@ bender.test( {
 			editable.fire( 'keydown', new CKEDITOR.dom.event( { keyCode: 37 } ) ); // LEFT
 			assert.areSame( p1, editor.getSelection().getSelectedElement(), 'Move left 2 - selectedElement' );
 			assert.isTrue( !!editor.getSelection().isFake, 'Move left 2 - isFake' );
-
-			editable.fire( 'keydown', new CKEDITOR.dom.event( { keyCode: 37 } ) ); // LEFT
-			assert.areSame( p1, editor.getSelection().getSelectedElement(), 'Move left 3 - selectedElement' );
-			assert.isTrue( !!editor.getSelection().isFake, 'Move left 3 - isFake' );
 		} );
 	},
 
@@ -745,7 +758,9 @@ bender.test( {
 			editor.getSelection().fake( ps );
 			editor.resetUndo();
 
-			editable.fire( 'keydown', getKeyEvent( 46, function() { prevented = true; } ) );
+			editable.fire( 'keydown', getKeyEvent( 46, function() {
+				prevented = true;
+			} ) );
 			assertCollapsedSelectionIn( editor, '<p>X</p><p>^bar</p>', 'Caret' );
 			assert.areSame( CKEDITOR.TRISTATE_OFF, editor.getCommand( 'undo' ).state, 'Undo is available' );
 			assert.isTrue( prevented, 'Was prevented' );
@@ -763,7 +778,9 @@ bender.test( {
 			editor.getSelection().fake( ps );
 			editor.resetUndo();
 
-			editable.fire( 'keydown', getKeyEvent( 8, function() { prevented = true; } ) );
+			editable.fire( 'keydown', getKeyEvent( 8, function() {
+				prevented = true;
+			} ) );
 			assertCollapsedSelectionIn( editor, '<p>bar^</p><p>X</p>', 'Caret' );
 			assert.areSame( CKEDITOR.TRISTATE_OFF, editor.getCommand( 'undo' ).state, 'Undo is available' );
 			assert.isTrue( prevented, 'Was prevented' );
@@ -781,7 +798,9 @@ bender.test( {
 			editor.getSelection().fake( ps );
 			editor.resetUndo();
 
-			editable.fire( 'keydown', getKeyEvent( 46, function() { prevented = true; } ) );
+			editable.fire( 'keydown', getKeyEvent( 46, function() {
+				prevented = true;
+			} ) );
 			assertCollapsedSelectionIn( editor, '<p>bar^bom</p>', 'Caret' );
 			assert.areSame( CKEDITOR.TRISTATE_OFF, editor.getCommand( 'undo' ).state, 'Undo is available' );
 			assert.isTrue( prevented, 'Was prevented' );
@@ -799,7 +818,9 @@ bender.test( {
 			editor.getSelection().fake( ps );
 			editor.resetUndo();
 
-			editable.fire( 'keydown', getKeyEvent( 8, function() { prevented = true; } ) );
+			editable.fire( 'keydown', getKeyEvent( 8, function() {
+				prevented = true;
+			} ) );
 			assertCollapsedSelectionIn( editor, '<p>bar^bom</p>', 'Caret' );
 			assert.areSame( CKEDITOR.TRISTATE_OFF, editor.getCommand( 'undo' ).state, 'Undo is available' );
 			assert.isTrue( prevented, 'Was prevented' );
@@ -817,7 +838,9 @@ bender.test( {
 			editor.getSelection().fake( ps );
 			editor.resetUndo();
 
-			editable.fire( 'keydown', getKeyEvent( 46, function() { prevented = true; } ) );
+			editable.fire( 'keydown', getKeyEvent( 46, function() {
+				prevented = true;
+			} ) );
 			assertCollapsedSelectionIn( editor, '<p>bar^</p>', 'Caret' );
 			assert.areSame( CKEDITOR.TRISTATE_OFF, editor.getCommand( 'undo' ).state, 'Undo is available' );
 			assert.isTrue( prevented, 'Was prevented' );
@@ -835,7 +858,9 @@ bender.test( {
 			editor.getSelection().fake( ps );
 			editor.resetUndo();
 
-			editable.fire( 'keydown', getKeyEvent( 8, function() { prevented = true; } ) );
+			editable.fire( 'keydown', getKeyEvent( 8, function() {
+				prevented = true;
+			} ) );
 			assertCollapsedSelectionIn( editor, '<p>^bar</p>', 'Caret' );
 			assert.areSame( CKEDITOR.TRISTATE_OFF, editor.getCommand( 'undo' ).state, 'Undo is available' );
 			assert.isTrue( prevented, 'Was prevented' );
@@ -853,7 +878,9 @@ bender.test( {
 			editor.getSelection().fake( ps );
 			editor.resetUndo();
 
-			editable.fire( 'keydown', getKeyEvent( 46, function() { prevented = true; } ) );
+			editable.fire( 'keydown', getKeyEvent( 46, function() {
+				prevented = true;
+			} ) );
 			assertCollapsedSelectionIn( editor, '<p>^\xa0</p>', 'Caret' );
 			assert.areSame( CKEDITOR.TRISTATE_OFF, editor.getCommand( 'undo' ).state, 'Undo is available' );
 			assert.isTrue( prevented, 'Was prevented' );
@@ -900,7 +927,6 @@ bender.test( {
 		this.editorBot.setData( '<p id="el1">foo</p><p id="target" contenteditable="false">bar</p><p></p><p id="el2">bom</p>', function() {
 			var el1 = editor.document.getById( 'el1' ),
 				el2 = editor.document.getById( 'el2' ),
-				target = editor.document.getById( 'target' ),
 				range = editor.createRange(),
 				testKeyNav = createTestKeyNavFn( editor, null );
 
@@ -1023,4 +1049,4 @@ bender.test( {
 			assert.isTrue( !!html.match( /\[/ ) && !!html.match( /\]/ ), 'Selection exists' );
 		} );
 	}
-} );
\ No newline at end of file
+} );
