@@ -1,4 +1,6 @@
 /* bender-tags: editor,unit */
+/* global testSelection, testSelectedElement, testSelectedText, testStartElement, rangy, doc, makeSelection,
+	convertRange, checkRangeEqual, checkSelection, assertSelectionsAreEqual, tools */
 
 bender.editor = {
 	config: {
@@ -6,9 +8,15 @@ bender.editor = {
 	}
 };
 
-bender.test(
-{
-	test_contructor : function() {
+var htmlComparisonOpts = {
+	compareSelection: true,
+	normalizeSelection: true
+};
+
+var isElement = CKEDITOR.dom.walker.nodeType( CKEDITOR.NODE_ELEMENT );
+
+bender.test( {
+	'test contructor': function() {
 		// Make the DOM selection at the beginning of the document.
 		var newRange = new CKEDITOR.dom.range( doc );
 		newRange.moveToPosition( doc.getBody(), CKEDITOR.POSITION_AFTER_START );
@@ -41,7 +49,7 @@ bender.test(
 		assert.areSame( 0, sel2.getRanges().length, 'selection.getRanges()' );
 	},
 
-	test_getSelection : function() {
+	'test getSelection': function() {
 		var sel = doc.getSelection();
 		assert.isFalse( !!sel.isLocked, 'selection.isLock' );
 		assert.areSame( sel.document.$, doc.$, 'selection.document' );
@@ -49,7 +57,7 @@ bender.test(
 	},
 
 	// Test getRanges/setRanges with various selection source.
-	test_ranges_manipulation : function() {
+	'test ranges manipulation': function() {
 		// Text selection.
 		testSelection( '<div>[foo]</div>' );
 		testSelection( '<p><strong>[foo</strong>]bar</p>' );
@@ -124,15 +132,121 @@ bender.test(
 			if ( ( CKEDITOR.env.ie && CKEDITOR.env.version < 9 ) || CKEDITOR.env.safari ) {
 				var selected = sel.getStartElement();
 				assert.isTrue( cell.equals( selected ) || cell.contains( selected ), 'selection is inside the cell' );
-			} else
+			} else {
 				assert.areSame( cell, sel.getSelectedElement(), 'cell is selected' );
+			}
 
 			// I saw some strange span being left by IE8. Let's check data to be safe.
 			assert.areSame( data, editor.getData().replace( /&nbsp;|\u00a0/, '' ), 'data is ok' );
 		} );
 	},
 
-	test_getSelectedElement : function() {
+	'test selectRanges - in empty block': function() {
+		if ( !CKEDITOR.env.needsBrFiller )
+			assert.ignore();
+
+		var editor = this.editor,
+			range = editor.createRange();
+
+		editor.editable().setHtml( '<p>foo</p><p id="target"><br /></p><p>bar</p>' );
+
+		var p = editor.document.getById( 'target' );
+		range.moveToPosition( p, CKEDITOR.POSITION_AFTER_START );
+
+		editor.getSelection().selectRanges( [ range ] );
+
+		assert.isInnerHtmlMatching(
+			'<p>foo</p><p id="target">^<br /></p><p>bar</p>',
+			bender.tools.selection.getWithHtml( editor ),
+			htmlComparisonOpts,
+			'selection was placed in the empty paragraph' );
+	},
+
+	'test selectRanges - after empty inline element': function() {
+		// IE8 can't handle this selection.
+		if ( CKEDITOR.env.ie && CKEDITOR.env.version == 8 ) {
+			assert.ignore();
+		}
+
+		var editor = this.editor,
+			range = editor.createRange();
+
+		editor.editable().setHtml( '<p>foo<strong id="target"></strong></p>' );
+
+		var strong = editor.document.getById( 'target' );
+		range.moveToPosition( strong, CKEDITOR.POSITION_AFTER_END );
+		editor.getSelection().selectRanges( [ range ] );
+
+		assert.areSame( strong, editor.getSelection().getRanges()[ 0 ].getPreviousNode( isElement ),
+			'the selection was located after the strong element' );
+	},
+
+	'test selectRanges - after empty inline element with the filler char': function() {
+		// IE8 can't handle this selection.
+		if ( CKEDITOR.env.ie && CKEDITOR.env.version == 8 ) {
+			assert.ignore();
+		}
+
+		var editor = this.editor,
+			range = editor.createRange();
+
+		editor.editable().setHtml( '<p>foo<strong id="target"></strong></p>' );
+
+		// Set the selection inside the strong element, so the filler char is created.
+		var strong = editor.document.getById( 'target' );
+		range.moveToPosition( strong, CKEDITOR.POSITION_AFTER_START );
+		editor.getSelection().selectRanges( [ range ] );
+
+		assert.areSame( 'strong', editor.getSelection().getStartElement().getName(),
+			'the selection was correctly placed inside empty strong element' );
+
+		range.moveToPosition( strong, CKEDITOR.POSITION_AFTER_END );
+		editor.getSelection().selectRanges( [ range ] );
+
+		assert.areSame( strong, editor.getSelection().getRanges()[ 0 ].getPreviousNode( isElement ),
+			'the selection was located after the strong element' );
+	},
+
+	'test selectRanges - after empty inline element with an empty text node': function() {
+		// IE8 can't handle this selection.
+		if ( CKEDITOR.env.ie && CKEDITOR.env.version == 8 ) {
+			assert.ignore();
+		}
+
+		var editor = this.editor,
+			range = editor.createRange();
+
+		editor.editable().setHtml( '<p>foo<strong id="target">x</strong></p>' );
+
+		// Set the selection inside the strong element, so the filler char is created.
+		var strong = editor.document.getById( 'target' );
+		strong.getFirst().setText( '' );
+
+		range.moveToPosition( strong, CKEDITOR.POSITION_AFTER_END );
+		editor.getSelection().selectRanges( [ range ] );
+
+		assert.areSame( strong, editor.getSelection().getRanges()[ 0 ].getPreviousNode( isElement ),
+			'the selection was located after the strong element' );
+	},
+
+	// #12690
+	'test selectRanges - inside empty inline element': function() {
+		var editor = this.editor,
+			range = editor.createRange();
+
+		editor.editable().setHtml( '<p>x<span style="font-size:48px"><strong id="target"></strong></span>x</p>' );
+
+		var strong = editor.document.getById( 'target' );
+		range.setStart( strong, 0 );
+		range.collapse( true );
+
+		editor.getSelection().selectRanges( [ range ] );
+
+		var sel = editor.getSelection();
+		assert.isTrue( strong.equals( sel.getStartElement() ) );
+	},
+
+	'test getSelectedElement': function() {
 		testSelectedElement( '[<img />]', 'img' );
 		testSelectedElement( '[<hr />]', 'hr' );
 		testSelectedElement( '[<b><i><img /></i>]</b>', 'img' );
@@ -153,9 +267,10 @@ bender.test(
 			editor.focus();
 			range.select();
 
-			var sel = editor.getSelection(),
-				// Cache range before getting selected element.
-				range = sel.getRanges()[ 0 ].clone();
+			var sel = editor.getSelection();
+
+			// Cache range before getting selected element.
+			range = sel.getRanges()[ 0 ].clone();
 
 			// Verify that test case works correctly. It might happen that
 			// getSelectedElement() has been already executed.
@@ -201,12 +316,12 @@ bender.test(
 		assert.areSame( 1, allRanges.length, 'only 1 range returned by getRanges()' );
 	},
 
-	test_getSelectedText : function() {
+	'test getSelectedText': function() {
 		testSelectedText( '[<b>foo</b>bar]', 'foobar' );
 		testSelectedText( '[<b>foo<img /></b>bar]', 'foobar' );
 	},
 
-	test_getStartElement : function() {
+	'test getStartElement': function() {
 		testStartElement( '<b>^foo</b>', 'b' );
 		testStartElement( '<b>foo^</b>', 'b' );
 		testStartElement( '<i><b>foo[</b>bar]</i>', 'i' );
@@ -214,7 +329,7 @@ bender.test(
 		testStartElement( '[<img />]', 'img' );
 	},
 
-	test_lock_unlock : function() {
+	'test lock and unlock': function() {
 		// Make the first selection.
 		var sourceRange = makeSelection( '<strong id="start">foo</strong>bar[<img />]' )[ 0 ];
 		var sel = doc.getSelection(),
@@ -239,14 +354,14 @@ bender.test(
 
 		sel.unlock();
 
-		var resultRange = sel.getRanges()[ 0 ];
+		resultRange = sel.getRanges()[ 0 ];
 		assert.isFalse( !!sel.isLocked, 'selection should not be marked as locked.' );
 		assert.isTrue( checkRangeEqual( resultRange, newRange ), 'get ranges result from locked selection doesn\'t match the original.' );
 		assert.isTrue( sel.getStartElement().is( 'strong' ), 'start element result from locked selection doesn\'t match the original.' );
 		assert.isTrue( sel.rev > initialRev, 'unlocked selection gets new rev' );
 	},
 
-	'test unlock outdated selection 1' : function() {
+	'test unlock outdated selection 1': function() {
 		makeSelection( '<p>a[b<b id="bold">c]d</b></p>' );
 
 		var sel = doc.getSelection(),
@@ -267,7 +382,7 @@ bender.test(
 		assert.isTrue( sel.rev > initialRev, 'New revision' );
 	},
 
-	'test unlock outdated selection 2' : function() {
+	'test unlock outdated selection 2': function() {
 		makeSelection( '<p>a<b id="bold">c[d<i>e]f</i></b></p>' );
 
 		var sel = doc.getSelection(),
@@ -288,9 +403,10 @@ bender.test(
 		assert.isTrue( sel.rev > initialRev, 'New revision' );
 	},
 
-	test_selectRanges_after_locked : function() {
+	'test selectRanges after locked': function() {
 		// Make the first selection.
-		var sourceRange = makeSelection( '<strong id="start">foo</strong>bar[<img />]' )[ 0 ];
+		makeSelection( '<strong id="start">foo</strong>bar[<img />]' )[ 0 ];
+
 		var sel = doc.getSelection(),
 			initialRev = sel.rev;
 
@@ -324,7 +440,7 @@ bender.test(
 		checkRangeEqual( domRange, newRange, 'actual selection range should be the same' );
 	},
 
-	test_removeAllRanges: function() {
+	'test removeAllRanges': function() {
 		var range = new CKEDITOR.dom.range( doc );
 		range.selectNodeContents( doc.getBody() );
 		range.select();
@@ -354,8 +470,9 @@ bender.test(
 			emptyRange.moveToPosition( startContainer, CKEDITOR.POSITION_AFTER_START );
 			checkSelection.call( sel, CKEDITOR.SELECTION_TEXT, startContainer, null, '', [ emptyRange ] );
 		}
-		else
+		else {
 			checkSelection.call( sel, CKEDITOR.SELECTION_NONE, null, null, '', 0 );
+		}
 	},
 
 	// #11500
@@ -373,7 +490,7 @@ bender.test(
 	},
 
 	// Check ranges return from selection is properly scoped.
-	'check selection ranges\' scope' : function() {
+	'check selection ranges\' scope': function() {
 		var editable = doc.getById( 'sandbox' );
 		tools.setHtmlWithSelection( editable, '<p>[foo]</p>' );
 		var sel = new CKEDITOR.dom.selection( editable ),
@@ -382,7 +499,7 @@ bender.test(
 			assert.areSame( ranges[ i ].root, editable );
 	},
 
-	'test get only editable ranges' : function() {
+	'test get only editable ranges': function() {
 		var editable = doc.getById( 'sandbox' ),
 			sel, ranges;
 
@@ -396,7 +513,7 @@ bender.test(
 		assert.areSame( 'bo', ranges[ 1 ].getEnclosedNode().getText() );
 	},
 
-	'test get only editable ranges 2' : function() {
+	'test get only editable ranges 2': function() {
 		if ( CKEDITOR.env.ie )
 			assert.ignore();
 
@@ -411,9 +528,8 @@ bender.test(
 		assert.areEqual( 0, ranges.length );
 	},
 
-	'selection scrolls into view' : function() {
-
-		function assertElementInViewport( el ) {
+	'selection scrolls into view': function() {
+		function assertElementInViewport() {
 			var view = doc.getWindow().getViewPaneSize();
 			var rect = marker.getClientRect();
 			assert.isTrue( rect.top > 0 && rect.top < view.height );
