@@ -1,10 +1,9 @@
 /* bender-tags: editor,unit */
 /* bender-ckeditor-plugins: basicstyles,toolbar */
 
-bender.editor = { config : { autoParagraph : false } };
+bender.editor = { config: { autoParagraph: false } };
 
-bender.test(
-{
+bender.test( {
 	'test apply range style across input element': function() {
 		var bot = this.editorBot;
 		bot.editor.filter.allow( 'input[type]' );
@@ -12,5 +11,4 @@ bender.test(
 		bot.execCommand( 'bold' );
 		assert.areSame( 'te<strong>xt<input type="button" />te</strong>xt', bot.getData( false, true ) );
 	}
-
 } );
\ No newline at end of file
