@@ -1,5 +1,6 @@
 /* bender-tags: editor,unit,widget */
 /* bender-ckeditor-plugins: toolbar,codesnippet */
+/* global widgetTestsTools */
 
 ( function() {
 	'use strict';
@@ -17,8 +18,8 @@
 		'test lang html':		assertDowncast( 'downcast-html', 1, 'codeSnippet' ),
 		'test lang unknown':	assertDowncast( 'downcast-unknown', 1, 'codeSnippet' ),
 		// Pre should not be downcasted.
-		'test pre only': 		assertDowncast( 'downcast-pre-only', 0 ),
+		'test pre only':		assertDowncast( 'downcast-pre-only', 0 ),
 		// Code tag alone should not be downcasted.
-		'test code only': 		assertDowncast( 'downcast-code-only', 0 ),
+		'test code only':		assertDowncast( 'downcast-code-only', 0 )
 	} );
 } )();
\ No newline at end of file
