@@ -1,5 +1,6 @@
 /* bender-tags: editor,unit,widget */
 /* bender-ckeditor-plugins: image2 */
+/* global widgetTestsTools, image2TestsTools */
 
 ( function() {
 	'use strict';
@@ -10,7 +11,7 @@
 
 	function assertWrapperAlignFloat( expected, msg ) {
 		return function( widget ) {
-			assert.areSame( expected, CKEDITOR.tools.trim( widget.wrapper.getStyle( 'float' ) ) );
+			assert.areSame( expected, CKEDITOR.tools.trim( widget.wrapper.getStyle( 'float' ) ), msg );
 		};
 	}
 
@@ -52,22 +53,7 @@
 		widgetTestsTools.assertWidget( config );
 	}
 
-	var getWidgetById = widgetTestsTools.getWidgetById,
-		fixHtml = image2TestsTools.fixHtml,
-
-		defs = {
-			alignInline: {
-				name: 'alignInline',
-				config: {}
-			},
-			alignClasses: {
-				name: 'alignClasses',
-				config: {
-					image2_alignClasses: [ 'l', 'c', 'r' ]
-				}
-			}
-		},
-
+	var fixHtml = image2TestsTools.fixHtml,
 		htmls = {
 			image: '<img src="_assets/foo.png" id="x" />',
 
@@ -156,32 +142,32 @@
 					'</span>' +
 					'<figcaption data-cke-display-name="caption" data-cke-filter="\\d+">[^<]+</figcaption>' +
 					'(<br />)?' +
-				'</figure>' ),
-		},
+				'</figure>' )
+		};
 
-		bots;
+	bender.editors = {
+		alignInline: {
+			name: 'alignInline',
+			config: {}
+		},
+		alignClasses: {
+			name: 'alignClasses',
+			config: {
+				image2_alignClasses: [ 'l', 'c', 'r' ]
+			}
+		}
+	};
+
+	bender.editorsConfig = {
+		allowedContent: true,
+		autoParagraph: false,
+		language: 'en'
+	};
 
 	bender.test( {
-		'async:init': function() {
-			var that = this;
-
-			for ( var d in defs ) {
-				CKEDITOR.tools.extend( defs[ d ].config, {
-					allowedContent: true,
-					autoParagraph: false,
-					language: 'en'
-				} );
-			}
-
-			bender.tools.setUpEditors( defs, function( editors, botCollection ) {
-				bots = botCollection;
-				that.callback( editors );
-			} );
-		},
-
 		'test non-captioned: center unaligned image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.image,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -192,7 +178,7 @@
 
 		'test non-captioned: center floated image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.imageAlignedRight,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignFloat( 'right', 'Widget\'s wrapper has float.' ),
@@ -203,7 +189,7 @@
 
 		'test non-captioned: float centered image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.imageCentered,
 				data: { align: 'right' },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -214,7 +200,7 @@
 
 		'test non-captioned: remove align of centered image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.imageCentered,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -225,7 +211,7 @@
 
 		'test non-captioned: remove align of floated image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.imageAlignedLeft,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignFloat( 'left', 'Widget\'s wrapper has float.' ),
@@ -236,7 +222,7 @@
 
 		'test captioned: center unaligned figure': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captioned,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -247,7 +233,7 @@
 
 		'test captioned: center floated figure': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedAlignLeft,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignFloat( 'left', 'Widget\'s wrapper has float.' ),
@@ -258,7 +244,7 @@
 
 		'test captioned: float centered figure': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedCentered,
 				data: { align: 'right' },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -269,7 +255,7 @@
 
 		'test captioned: remove align of centered figure': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedCentered,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -280,7 +266,7 @@
 
 		'test captioned: remove align of floated figure': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedAlignLeft,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignFloat( 'left', 'Widget\'s wrapper has float.' ),
@@ -293,7 +279,7 @@
 
 		'test transition: center, add caption to unaligned image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.image,
 				data: { align: 'center', hasCaption: true },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -304,7 +290,7 @@
 
 		'test transition: remove align and caption of centered figure': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedCentered,
 				data: { align: 'none', hasCaption: false },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -315,7 +301,7 @@
 
 		'test transition: remove caption of centered figure': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedCentered,
 				data: { hasCaption: false },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -326,7 +312,7 @@
 
 		'test transition: add caption to centered image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.imageCentered,
 				data: { hasCaption: true },
 				assertCreated: assertWrapperAlignFloat( '', 'Widget\'s wrapper has no float.' ),
@@ -337,7 +323,7 @@
 
 		'test transition: add caption to floated image': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.imageAlignedLeft,
 				data: { hasCaption: true },
 				assertCreated: assertWrapperAlignFloat( 'left', 'Widget\'s wrapper has float.' ),
@@ -350,7 +336,7 @@
 
 		'test block wrapping: wrap widget in a block when it becomes inline (caption lost)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedAlignLeft,
 				data: { hasCaption: false },
 				dom: new RegExp(
@@ -362,7 +348,7 @@
 
 		'test block wrapping: wrap widget in a block when it becomes inline (align lost)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.imageCentered,
 				data: { align: 'none' },
 				dom: new RegExp(
@@ -374,7 +360,7 @@
 
 		'test block wrapping: wrap widget in a block when it becomes inline (caption and align lost)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.captionedAlignLeft,
 				data: {
 					hasCaption: false,
@@ -389,7 +375,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets captioned)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: htmls.image,
 				data: { hasCaption: true },
 				dom: doms.captioned
@@ -398,7 +384,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets captioned, siblings before)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: '<p>xx' + htmls.image + '</p>',
 				data: { hasCaption: true },
 				dom: new RegExp(
@@ -416,7 +402,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets captioned, siblings after)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: '<p>' + htmls.image + 'xx</p>',
 				data: { hasCaption: true },
 				dom: new RegExp(
@@ -434,7 +420,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets captioned, two siblings)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: '<p>x' + htmls.image + 'x</p>',
 				data: { hasCaption: true },
 				dom: new RegExp(
@@ -453,7 +439,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets centered)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: '<p>' + htmls.image + '</p>',
 				data: { align: 'center' },
 				dom: new RegExp(
@@ -468,7 +454,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets centered, siblings before)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: '<p>xx' + htmls.image + '</p>',
 				data: { align: 'center' },
 				dom: new RegExp(
@@ -484,7 +470,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets centered, siblings after)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: '<p>' + htmls.image + 'xx</p>',
 				data: { align: 'center' },
 				dom: new RegExp(
@@ -500,7 +486,7 @@
 
 		'test block wrapping: de-wrap widget from block when it becomes a block (gets centered, two siblings)': function() {
 			assertWidget( {
-				bot: bots.alignInline,
+				bot: this.editorBots.alignInline,
 				html: '<p>x' + htmls.image + 'x</p>',
 				data: { align: 'center' },
 				dom: new RegExp(
@@ -519,7 +505,7 @@
 
 		'test non-captioned (alignClasses): center unaligned image': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.image,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignClasses( null ),
@@ -530,7 +516,7 @@
 
 		'test non-captioned (alignClasses): center aligned image': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.imageAlignedClassLeft,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignClasses( 'l' ),
@@ -541,7 +527,7 @@
 
 		'test non-captioned (alignClasses): align centered image': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.imageCenteredClass,
 				data: { align: 'right' },
 				assertCreated: assertWrapperAlignClasses( 'c', true ),
@@ -552,7 +538,7 @@
 
 		'test non-captioned (alignClasses): remove align of centered image': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.imageCenteredClass,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignClasses( 'c', true ),
@@ -563,7 +549,7 @@
 
 		'test non-captioned (alignClasses): remove align of aligned image': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.imageAlignedClassRight,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignClasses( 'r' ),
@@ -574,7 +560,7 @@
 
 		'test captioned (alignClasses): center unaligned figure': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.captioned,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignClasses( null ),
@@ -585,7 +571,7 @@
 
 		'test captioned (alignClasses): center aligned figure': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.captionedAlignedClassLeft,
 				data: { align: 'center' },
 				assertCreated: assertWrapperAlignClasses( 'l' ),
@@ -596,7 +582,7 @@
 
 		'test captioned (alignClasses): align centered figure': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.captionedCenteredClass,
 				data: { align: 'right' },
 				assertCreated: assertWrapperAlignClasses( 'c' ),
@@ -607,7 +593,7 @@
 
 		'test captioned (alignClasses): remove align of centered figure': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.captionedCenteredClass,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignClasses( 'c' ),
@@ -618,7 +604,7 @@
 
 		'test captioned (alignClasses): remove align of aligned figure': function() {
 			assertWidget( {
-				bot: bots.alignClasses,
+				bot: this.editorBots.alignClasses,
 				html: htmls.captionedAlignedClassRight,
 				data: { align: 'none' },
 				assertCreated: assertWrapperAlignClasses( 'r' ),
